/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 55 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 432 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 881 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_SCALAR;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_NUMBER;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_value().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1081 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1155 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1176 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1379 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1608 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 264 "parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned char
#define YYNOCODE 244
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 70
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  Expr* yy44;
  int yy58;
  With* yy91;
  Select* yy99;
  struct LimitVal yy112;
  ExprSpan yy190;
  TriggerStep* yy203;
  struct alter_args yy206;
  struct TrigEvent yy234;
  struct SrcList * yy254;
  IdList* yy258;
  SrcList* yy367;
  ExprList* yy412;
  struct Token yy415;
  struct type_def yy438;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             413
#define YYNRULE              293
#define YY_MAX_SHIFT         412
#define YY_MIN_SHIFTREDUCE   612
#define YY_MAX_SHIFTREDUCE   904
#define YY_MIN_REDUCE        905
#define YY_MAX_REDUCE        1197
#define YY_ERROR_ACTION      1198
#define YY_ACCEPT_ACTION     1199
#define YY_NO_ACTION         1200
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1398)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    57,   58,  273,  295,  774,  774,  784,  787,   55,   55,
 /*    10 */    56,   56,   56,   56,  288,   54,   54,   54,   54,   53,
 /*    20 */    53,   52,   52,   52,   51,  296,  627,   57,   58,  273,
 /*    30 */   295,  774,  774,  784,  787,   55,   55,   56,   56,   56,
 /*    40 */    56,  888,   54,   54,   54,   54,   53,   53,   52,   52,
 /*    50 */    52,   51,  296,   58,  273,  295,  774,  774,  784,  787,
 /*    60 */    55,   55,   56,   56,   56,   56,  888,   54,   54,   54,
 /*    70 */    54,   53,   53,   52,   52,   52,   51,  296,  863,  864,
 /*    80 */   259,  867,  867,  867,  868,  868,  296,  204,   52,   52,
 /*    90 */    52,   51,  296,   57,   58,  273,  295,  774,  774,  784,
 /*   100 */   787,   55,   55,   56,   56,   56,   56,  627,   54,   54,
 /*   110 */    54,   54,   53,   53,   52,   52,   52,   51,  296,   53,
 /*   120 */    53,   52,   52,   52,   51,  296, 1199,  412,    2,  723,
 /*   130 */   724,  628,  628,   35,   56,   56,   56,   56,   49,   54,
 /*   140 */    54,   54,   54,   53,   53,   52,   52,   52,   51,  296,
 /*   150 */   224,  257,   59,  359,  638,  358,  199,  212,   57,   58,
 /*   160 */   273,  295,  774,  774,  784,  787,   55,   55,   56,   56,
 /*   170 */    56,   56,  120,   54,   54,   54,   54,   53,   53,   52,
 /*   180 */    52,   52,   51,  296,   54,   54,   54,   54,   53,   53,
 /*   190 */    52,   52,   52,   51,  296,  411,  411,  639,   41,  265,
 /*   200 */    39,  117,  223,   57,   58,  273,  295,  774,  774,  784,
 /*   210 */   787,   55,   55,   56,   56,   56,   56,  694,   54,   54,
 /*   220 */    54,   54,   53,   53,   52,   52,   52,   51,  296,  307,
 /*   230 */    50,   48,  174,  681,  852,  843,   66,  222,  105,  398,
 /*   240 */   221,  852,  632,  757,  324,  829,  752,  306,   57,   58,
 /*   250 */   273,  295,  774,  774,  784,  787,   55,   55,   56,   56,
 /*   260 */    56,   56,  330,   54,   54,   54,   54,   53,   53,   52,
 /*   270 */    52,   52,   51,  296,  113,  613,  300,   67,  829,  298,
 /*   280 */   298,  268,  328,  277,  164,  271,  650,  765,  756,  756,
 /*   290 */   758,  298,  750,   57,   58,  273,  295,  774,  774,  784,
 /*   300 */   787,   55,   55,   56,   56,   56,   56,  631,   54,   54,
 /*   310 */    54,   54,   53,   53,   52,   52,   52,   51,  296,  113,
 /*   320 */    51,  296,  879,  272,  138,  875,  269,  628,  628,  879,
 /*   330 */   271,  651,  751,  641,  211,  366,  875,  634,   57,   58,
 /*   340 */   273,  295,  774,  774,  784,  787,   55,   55,   56,   56,
 /*   350 */    56,   56,  323,   54,   54,   54,   54,   53,   53,   52,
 /*   360 */    52,   52,   51,  296,   57,   58,  273,  295,  774,  774,
 /*   370 */   784,  787,   55,   55,   56,   56,   56,   56,  633,   54,
 /*   380 */    54,   54,   54,   53,   53,   52,   52,   52,   51,  296,
 /*   390 */    57,   58,  273,  295,  774,  774,  784,  787,   55,   55,
 /*   400 */    56,   56,   56,   56,  347,   54,   54,   54,   54,   53,
 /*   410 */    53,   52,   52,   52,   51,  296,   57,   58,  273,  295,
 /*   420 */   774,  774,  784,  787,   55,   55,   56,   56,   56,   56,
 /*   430 */   722,   54,   54,   54,   54,   53,   53,   52,   52,   52,
 /*   440 */    51,  296,  701,   57,   47,  273,  295,  774,  774,  784,
 /*   450 */   787,   55,   55,   56,   56,   56,   56,   37,   54,   54,
 /*   460 */    54,   54,   53,   53,   52,   52,   52,   51,  296,  673,
 /*   470 */   673,  410,  203,  617,  409,  214,  266,  114,  376,  623,
 /*   480 */    50,   48,  174,   40,  238,  273,  295,  774,  774,  784,
 /*   490 */   787,   55,   55,   56,   56,   56,   56,   45,   54,   54,
 /*   500 */    54,   54,   53,   53,   52,   52,   52,   51,  296,  312,
 /*   510 */   332,  746,  408,  161,   42,   43,  775,  775,  785,  788,
 /*   520 */   750,   44,  387,   45,   21,   21,  219,  319,  815,  270,
 /*   530 */   279,  278,  400,    3, 1094,  343,  297,  297,  275,  340,
 /*   540 */    42,   43,  211,  366,  826,  721,  825,   44,   50,   48,
 /*   550 */   174,  315,  628,  628,  322,  389,  408,  658,  400,    3,
 /*   560 */   231,  757,  297,  297,  752,  356,  182,  332,   73,   73,
 /*   570 */   659,  183,    5,  310,  120,  888,  402,  895,  668,  899,
 /*   580 */   281,  389,  314,  313,  314,  668,  897,  757,  898,  289,
 /*   590 */   752,  363,  754,  302,  105,   50,   48,  174,  170,  708,
 /*   600 */   888,  815,  817,  815,  408,  364,  756,  756,  758,  759,
 /*   610 */   406,  892,   17,  354,  351,  358,   91,   91,  754,  405,
 /*   620 */   402,  204,  900,  327,  900,  120,   45,  350,  189,  175,
 /*   630 */   175,  165,  756,  756,  758,  759,  406,  892,   17,  382,
 /*   640 */   291,  369,  105,   42,   43,  695,  812,  408,  291,  707,
 /*   650 */    44,  120,   45,  384,  383,  317,  162,  708,  248,   91,
 /*   660 */    91,  400,    3,  287,  334,  297,  297,  708,  402,   42,
 /*   670 */    43,  287,  121,  276,  240,  239,   44, 1170, 1170,  156,
 /*   680 */   155,  250,  408,  309,  389, 1169, 1169,  400,    3,  408,
 /*   690 */   757,  297,  297,  752,   91,   91,  384,  367,   61,  846,
 /*   700 */   405,   90,   90,  889,  889,  212,  154,  246,  671,  671,
 /*   710 */   389,  402,  847,  212,  154,  246,  757,  176,  823,  752,
 /*   720 */   238,  754,  848,  674,  162,  708,  757,  746,  238,  752,
 /*   730 */   675,  384,  372,  173,  172,  756,  756,  758,  759,  406,
 /*   740 */   892,   17,  230,  329,  408,  338,  402,  754,  843,  628,
 /*   750 */   628,  105,  141,  402,  240,  239,   91,   91,  256,  890,
 /*   760 */   710,  756,  756,  758,  759,  406,  892,   17,  889,  889,
 /*   770 */   235,  756,  756,  758,  921,  330,  231,   56,   56,   56,
 /*   780 */    56,  750,   54,   54,   54,   54,   53,   53,   52,   52,
 /*   790 */    52,   51,  296,  384,  381,  339,  120,  146,  408,  640,
 /*   800 */   408,  240,  239,  408,  746,  408,  167,  807,  402,  361,
 /*   810 */    91,   91,   91,   91,  408,   21,   21,   21,   21,  230,
 /*   820 */   329,  408,  234,  408,  890,  709,   21,   21,  188,  284,
 /*   830 */   408,  286,  370,   91,   91,   91,   91,  750,  755,  408,
 /*   840 */   198,  282,   21,   21,   20,   20,  408,  384,  401,  384,
 /*   850 */   362,   77,   77,  231,  175,  175,  379,  338,   78,   78,
 /*   860 */   227,  160,  402,  408,  402,  338,  369,  402,  408,  402,
 /*   870 */   292,  408,  377,  120,   32,   79,   79,  691,  402,  408,
 /*   880 */    80,   80,  690,   81,   81,  402,  139,  402,  408,  628,
 /*   890 */   628,   70,   70,  408,  402,  408,  402,  283,  888,  408,
 /*   900 */    72,   72,  822,  402,  822,   82,   82,   83,   83,  408,
 /*   910 */   402,   84,   84, 1151, 1151,  812,  408,  255,  408,  628,
 /*   920 */   628,   22,   22,  888,  408,  252,  408,  402,   85,   85,
 /*   930 */    86,   86,  402,  408,    8,  402,   87,   87,   74,   74,
 /*   940 */   229,  408,  285,  402,  204,   88,   88,  707,  191,  408,
 /*   950 */   217,  120,  402,   89,   89,  316,  408,  402,  408,  402,
 /*   960 */   707,   75,   75,  402,  408,  707,  408,  257,  110,  110,
 /*   970 */   111,  111,  408,  402,  408,  750,  112,  112,   95,   95,
 /*   980 */   402,  735,  402,  408,   76,   76,   98,   98,  402,  408,
 /*   990 */   402,  652,  653,  654,  218,   92,   92,  402,  408,  184,
 /*  1000 */   373,   99,   99,  408,  743,  402,  408,  105,  856,  144,
 /*  1010 */    97,   97,  408,  402,  336,  109,  109,  120,  104,  104,
 /*  1020 */   402,  408,  402,   68,  103,  103,  628,  628,  402,  408,
 /*  1030 */   402,  408,  812,  102,  102,  293,  402,  408,  402,  851,
 /*  1040 */   374,  100,  100,  101,  101,  408,  857,  402,  408,   94,
 /*  1050 */    94,  696,  408,  402,  337,  394,  408,   96,   96,  294,
 /*  1060 */    93,   93,  402,  371,   69,   69,  105,  402,   71,   71,
 /*  1070 */   402,  628,  628,  846,  301,  854,  402,  707,  887,  707,
 /*  1080 */     1,  159,  172,  628,  628,  402,  847,   34,  305,  365,
 /*  1090 */   707,  686,  686,  402,  707,  402,  848,  388,  707,  707,
 /*  1100 */   210,  402,  841,  683,  680,  105,  821,  105,  821,  402,
 /*  1110 */    23,  185,  402,  849,  369,  391,  402,   63,  105,  395,
 /*  1120 */   402,  644,  105,  399,  813,  407,  105,  311,  677,  723,
 /*  1130 */   724,  664,  676,  226,  152,  691,  853,   34,  303,  206,
 /*  1140 */   690,  748,  202,  331,  202,  738,   62,  280,  333,  202,
 /*  1150 */   806,   34,  348,  206,  667,   34,  245,  642,  642,  157,
 /*  1160 */   158,  657,  656,  665,  688,   36,  717,  202,  318,  244,
 /*  1170 */   220,  810,  206,  320,  840,  760,  760,  626,   19,  166,
 /*  1180 */   228,  838,  837,  341,  335,  352,  342,  233,  622,  254,
 /*  1190 */   243,  237,  778,  390,    7,  242,  715,  749,  697,  811,
 /*  1200 */   258,  153,  264,  629,  620,  619,  621,  274,  145,  136,
 /*  1210 */   115,  106,  125,   32,  127,  734,  321,  824,   24,  216,
 /*  1220 */   326,  225,  346,  187,  194,  147,  195,  196,  290,  344,
 /*  1230 */   355,  107,  357,  236,  644,  129,  108,  360,  647,  375,
 /*  1240 */   186,  131,  132,  140,  745,  637,  662,  648,  792,  241,
 /*  1250 */   661,  636,  635,  842,   31,    6,  404,  866,   38,   60,
 /*  1260 */   380,  393,  378,  397,    9,  872,   33,  874,  213,   64,
 /*  1270 */   215,  615,   65,  299,  855,   10,  705,  177,  122,  304,
 /*  1280 */   178,  179,  180,  247,  308,  123,  706,  819,  181,  249,
 /*  1290 */   124,  704,  251,  263,  703,  687,  253,  818,  262,  260,
 /*  1300 */   816,  744,  261,  126,  118,  128,  130,  678,  827,  202,
 /*  1310 */   133,  325,  205,  134,  836,  901,  135,   25,   26,   27,
 /*  1320 */   137,   28,  119,  839,  190,  192,  835,   11,   18,  193,
 /*  1330 */   148,  625,  244,  232,  345,  197,  142,  349,   12,  157,
 /*  1340 */   666,   13,  353,  660,  158,   29,  200,  116,  685,  385,
 /*  1350 */   764,  201,  762,  790,   14,   30,  689,    4,  711,  168,
 /*  1360 */   368,  169,  171,  716,  143,   36,  805,   15,   34,  386,
 /*  1370 */    16,  209,  791,  789,  845,  844,  163,  392,  861,  149,
 /*  1380 */   207,  862,  150,  794,  793,  151,  403,  763,  208,  396,
 /*  1390 */   865,  761,   46,  779,  267,  616,  612, 1162,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,   80,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,  161,    5,    6,    7,
 /*    30 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    40 */    18,   46,   20,   21,   22,   23,   24,   25,   26,   27,
 /*    50 */    28,   29,   30,    6,    7,    8,    9,   10,   11,   12,
 /*    60 */    13,   14,   15,   16,   17,   18,   71,   20,   21,   22,
 /*    70 */    23,   24,   25,   26,   27,   28,   29,   30,  137,  138,
 /*    80 */   139,  140,  141,  142,  143,  144,   30,   92,   26,   27,
 /*    90 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   100 */    12,   13,   14,   15,   16,   17,   18,  242,   20,   21,
 /*   110 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   24,
 /*   120 */    25,   26,   27,   28,   29,   30,  146,  147,  148,  107,
 /*   130 */   108,   46,   47,   45,   15,   16,   17,   18,   19,   20,
 /*   140 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   150 */    39,  152,   64,   75,   76,   77,   78,   72,    5,    6,
 /*   160 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   170 */    17,   18,  135,   20,   21,   22,   23,   24,   25,   26,
 /*   180 */    27,   28,   29,   30,   20,   21,   22,   23,   24,   25,
 /*   190 */    26,   27,   28,   29,   30,  149,  150,   44,  123,  153,
 /*   200 */   125,  155,   91,    5,    6,    7,    8,    9,   10,   11,
 /*   210 */    12,   13,   14,   15,   16,   17,   18,  204,   20,   21,
 /*   220 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   50,
 /*   230 */   217,  218,  219,  187,  173,  187,  190,  126,  190,  240,
 /*   240 */   129,  180,   44,   71,   81,   82,   74,   68,    5,    6,
 /*   250 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   260 */    17,   18,  214,   20,   21,   22,   23,   24,   25,   26,
 /*   270 */    27,   28,   29,   30,  152,    1,    2,  229,  115,  157,
 /*   280 */   158,  159,  234,  237,  238,  163,  176,   44,  116,  117,
 /*   290 */   118,  169,  152,    5,    6,    7,    8,    9,   10,   11,
 /*   300 */    12,   13,   14,   15,   16,   17,   18,  164,   20,   21,
 /*   310 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  152,
 /*   320 */    29,   30,  162,  163,   43,  158,  159,   46,   47,  169,
 /*   330 */   163,  176,   44,  173,   97,   98,  169,  164,    5,    6,
 /*   340 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   350 */    17,   18,  212,   20,   21,   22,   23,   24,   25,   26,
 /*   360 */    27,   28,   29,   30,    5,    6,    7,    8,    9,   10,
 /*   370 */    11,   12,   13,   14,   15,   16,   17,   18,  164,   20,
 /*   380 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   390 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   400 */    15,   16,   17,   18,    7,   20,   21,   22,   23,   24,
 /*   410 */    25,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*   420 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   430 */   167,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   440 */    29,   30,  207,    5,    6,    7,    8,    9,   10,   11,
 /*   450 */    12,   13,   14,   15,   16,   17,   18,  124,   20,   21,
 /*   460 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  183,
 /*   470 */   184,   32,  204,   34,   35,   36,   37,   92,  211,   40,
 /*   480 */   217,  218,  219,  124,   87,    7,    8,    9,   10,   11,
 /*   490 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   500 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  152,
 /*   510 */   152,   66,  152,  211,   24,   25,    9,   10,   11,   12,
 /*   520 */   152,   31,  184,    7,  164,  165,   81,   82,  152,   90,
 /*   530 */    24,   25,   42,   43,   44,  224,   46,   47,  178,  228,
 /*   540 */    24,   25,   97,   98,   51,  167,   53,   31,  217,  218,
 /*   550 */   219,  112,   46,   47,   61,   65,  152,   54,   42,   43,
 /*   560 */   115,   71,   46,   47,   74,   62,  127,  152,  164,  165,
 /*   570 */    67,  213,   43,  134,  135,   46,  216,   71,  173,   73,
 /*   580 */   212,   65,  225,  226,  227,  180,   80,   71,   82,   86,
 /*   590 */    74,  187,  102,  239,  190,  217,  218,  219,   44,   45,
 /*   600 */    71,  225,  226,  227,  152,  201,  116,  117,  118,  119,
 /*   610 */   120,  121,  122,   75,   76,   77,  164,  165,  102,  161,
 /*   620 */   216,   92,  116,  231,  118,  135,    7,   89,  213,  188,
 /*   630 */   189,  230,  116,  117,  118,  119,  120,  121,  122,  187,
 /*   640 */     7,  200,  190,   24,   25,   26,  152,  152,    7,  152,
 /*   650 */    31,  135,    7,  201,  202,  214,  102,  103,  204,  164,
 /*   660 */   165,   42,   43,   30,  152,   46,   47,   45,  216,   24,
 /*   670 */    25,   30,  172,  179,  174,  175,   31,   44,   45,   24,
 /*   680 */    25,  204,  152,  186,   65,   44,   45,   42,   43,  152,
 /*   690 */    71,   46,   47,   74,  164,  165,  201,  202,   43,   35,
 /*   700 */   242,  164,  165,   46,   47,   72,   73,   74,  183,  184,
 /*   710 */    65,  216,   48,   72,   73,   74,   71,   43,   57,   74,
 /*   720 */    87,  102,   58,   59,  102,  103,   71,   66,   87,   74,
 /*   730 */    66,  201,  202,  205,  206,  116,  117,  118,  119,  120,
 /*   740 */   121,  122,   81,   82,  152,  152,  216,  102,  187,   46,
 /*   750 */    47,  190,  172,  216,  174,  175,  164,  165,  221,  102,
 /*   760 */   103,  116,  117,  118,  119,  120,  121,  122,   46,   47,
 /*   770 */    39,  116,  117,  118,  100,  214,  115,   15,   16,   17,
 /*   780 */    18,  152,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   790 */    28,   29,   30,  201,  202,  234,  135,  191,  152,  172,
 /*   800 */   152,  174,  175,  152,   66,  152,   45,   76,  216,   26,
 /*   810 */   164,  165,  164,  165,  152,  164,  165,  164,  165,   81,
 /*   820 */    82,  152,   91,  152,  102,  103,  164,  165,  235,  178,
 /*   830 */   152,  178,  152,  164,  165,  164,  165,  152,  152,  152,
 /*   840 */   178,  212,  164,  165,  164,  165,  152,  201,  202,  201,
 /*   850 */   202,  164,  165,  115,  188,  189,  178,  152,  164,  165,
 /*   860 */   129,  152,  216,  152,  216,  152,  200,  216,  152,  216,
 /*   870 */   201,  152,  201,  135,  113,  164,  165,   94,  216,  152,
 /*   880 */   164,  165,   99,  164,  165,  216,   43,  216,  152,   46,
 /*   890 */    47,  164,  165,  152,  216,  152,  216,  212,   46,  152,
 /*   900 */   164,  165,  116,  216,  118,  164,  165,  164,  165,  152,
 /*   910 */   216,  164,  165,   97,   98,  152,  152,  152,  152,   46,
 /*   920 */    47,  164,  165,   71,  152,  204,  152,  216,  164,  165,
 /*   930 */   164,  165,  216,  152,  192,  216,  164,  165,  164,  165,
 /*   940 */   235,  152,  179,  216,   92,  164,  165,  152,  235,  152,
 /*   950 */   152,  135,  216,  164,  165,   73,  152,  216,  152,  216,
 /*   960 */   152,  164,  165,  216,  152,  152,  152,  152,  164,  165,
 /*   970 */   164,  165,  152,  216,  152,  152,  164,  165,  164,  165,
 /*   980 */   216,  186,  216,  152,  164,  165,  164,  165,  216,  152,
 /*   990 */   216,   83,   84,   85,  186,  164,  165,  216,  152,  186,
 /*  1000 */     7,  164,  165,  152,  187,  216,  152,  190,  152,  136,
 /*  1010 */   164,  165,  152,  216,    7,  164,  165,  135,  164,  165,
 /*  1020 */   216,  152,  216,   43,  164,  165,   46,   47,  216,  152,
 /*  1030 */   216,  152,  152,  164,  165,  212,  216,  152,  216,  152,
 /*  1040 */    47,  164,  165,  164,  165,  152,  152,  216,  152,  164,
 /*  1050 */   165,   26,  152,  216,   47,  240,  152,  164,  165,  179,
 /*  1060 */   164,  165,  216,  187,  164,  165,  190,  216,  164,  165,
 /*  1070 */   216,   46,   47,   35,   75,   76,  216,  152,   45,  152,
 /*  1080 */    43,  205,  206,   46,   47,  216,   48,   45,   89,   93,
 /*  1090 */   152,   95,   96,  216,  152,  216,   58,   59,  152,  152,
 /*  1100 */   193,  216,  187,  189,  187,  190,  116,  190,  118,  216,
 /*  1110 */   203,  186,  216,  186,  200,  187,  216,   14,  190,  187,
 /*  1120 */   216,   79,  190,  187,  186,    7,  190,  152,  186,  107,
 /*  1130 */   108,   56,  186,  186,  101,   94,   44,   45,   44,   45,
 /*  1140 */    99,   44,   45,   44,   45,  195,   43,  152,   44,   45,
 /*  1150 */    44,   45,   44,   45,   44,   45,   74,   46,   47,   81,
 /*  1160 */    82,   73,   74,   88,   44,   45,   44,   45,  208,   87,
 /*  1170 */   208,   44,   45,  152,  195,   46,   47,   44,   45,  152,
 /*  1180 */   236,  152,  152,  152,  236,  168,  152,  152,  152,  208,
 /*  1190 */   167,  152,   74,  223,  192,  152,  152,  152,  152,  152,
 /*  1200 */   152,  192,  194,  152,  152,  152,  152,    9,   43,   43,
 /*  1210 */     5,  171,  215,  113,  182,  195,   41,  233,  123,  170,
 /*  1220 */   131,  232,   41,  156,  156,  215,  156,  156,   60,  170,
 /*  1230 */    80,  171,   80,  170,   79,  185,  171,   80,  174,  105,
 /*  1240 */   185,  185,  185,  182,  182,  168,  177,  175,  220,  170,
 /*  1250 */   177,  166,  166,  195,   80,   43,   43,  241,  123,  111,
 /*  1260 */   106,  170,  109,  170,   43,   36,  110,  154,  151,  160,
 /*  1270 */   151,    4,  160,    3,   63,   43,  210,   78,   43,   63,
 /*  1280 */    38,   72,   72,  209,   90,   39,  210,   44,  100,  209,
 /*  1290 */    39,  210,  209,  195,  210,  199,  209,   44,  196,  198,
 /*  1300 */    44,   98,  197,  114,   86,  101,   80,   42,  130,   45,
 /*  1310 */   130,  132,  222,   80,    1,  133,  101,   14,   14,   14,
 /*  1320 */   114,   14,   86,   47,  104,  100,    1,   43,  128,   80,
 /*  1330 */    92,   42,   87,  126,    7,   78,   43,   63,   43,   81,
 /*  1340 */    44,   43,   63,   49,   82,   43,   63,   55,   94,   71,
 /*  1350 */    44,  104,   44,   44,   43,   45,   44,   43,  103,  100,
 /*  1360 */    45,   44,   44,   47,   43,   45,   44,  104,   45,   45,
 /*  1370 */   104,  100,   44,   44,   44,   44,   43,   92,   44,   43,
 /*  1380 */    45,   44,   43,   57,   44,   43,  118,   44,   43,   92,
 /*  1390 */    44,   44,   43,   74,   38,   33,    1,    0,
};
#define YY_SHIFT_USE_DFLT (1398)
#define YY_SHIFT_COUNT    (412)
#define YY_SHIFT_MIN      (-66)
#define YY_SHIFT_MAX      (1397)
static const short yy_shift_ofst[] = {
 /*     0 */   274,  490,  439,  516,  645,  645,  645,  645,  645,   85,
 /*    10 */   645,  645,  645,  645,  645,  645,  645,  645,  738,   85,
 /*    20 */    -5,   22,   22,  619,  645,  645,  645,  645,  645,  645,
 /*    30 */   645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
 /*    40 */   645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
 /*    50 */   645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
 /*    60 */   645,  645,  506,  506,  633,  641,  445,  661,  816,   88,
 /*    70 */   153,  198,  243,  288,  333,  359,  385,  411,  411,  411,
 /*    80 */   411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
 /*    90 */   411,  411,  438,  411,   47,  478,  478,  119,  762,  762,
 /*   100 */   762,  164,   95,   62,  291,  237,  -66,  -66,  -66,   56,
 /*   110 */  1398, 1398, 1398,  -59,  -59,  664,  664,  731,  281,  281,
 /*   120 */   873,  397,  703,  703,  703,  882,  703,  703,  703,  703,
 /*   130 */   703,  703,  703,  703,  703,  703,  703,  703,  703,  703,
 /*   140 */   703,  397,  703,  703,  703,  703,  237,   37,   37,   37,
 /*   150 */    37,   37, 1398, 1398,  655,  172,  172,  503,  503,  554,
 /*   160 */   529,  657,  722, 1038,  999,  163,  493,  843, 1025,  852,
 /*   170 */   852,  852,  980,  622, 1037,  996,  783,  703,  703,  703,
 /*   180 */   703,  703,  703,  761,  993,  993,  703,  703, 1007,  761,
 /*   190 */   703, 1007,  703,  703,  703,  703,  703,  703, 1042,  703,
 /*   200 */  1022,  703,  703,  993,  703,   75,  703,  703, 1041,  703,
 /*   210 */  1033, 1041,  703,  703,  703,  703, 1198, 1165, 1166, 1205,
 /*   220 */  1100, 1175, 1175, 1175, 1175, 1095, 1089, 1181, 1100, 1166,
 /*   230 */  1205, 1205, 1181, 1165, 1181, 1181, 1198, 1165, 1168, 1150,
 /*   240 */  1152, 1198, 1165, 1155, 1168, 1157, 1157, 1134, 1174, 1134,
 /*   250 */  1174, 1134, 1174, 1134, 1174, 1212, 1135, 1165, 1165, 1213,
 /*   260 */  1148, 1154, 1156, 1153, 1100, 1221, 1229, 1229, 1398, 1398,
 /*   270 */   111,  538,   78,  507,  908, 1092, 1094,  179,  786,  990,
 /*   280 */  1103, 1097, 1099, 1104, 1106, 1108, 1110, 1111, 1078, 1088,
 /*   290 */  1075, 1082, 1120, 1122, 1127, 1118, 1129,  674, 1133, 1267,
 /*   300 */  1270, 1211, 1232, 1199, 1235, 1216, 1242, 1209, 1210, 1194,
 /*   310 */  1246, 1243, 1188, 1253, 1256, 1251, 1203, 1189, 1218, 1204,
 /*   320 */  1226, 1265, 1178, 1264, 1180, 1182, 1179, 1233, 1313, 1215,
 /*   330 */  1206, 1303, 1304, 1305, 1307, 1236, 1276, 1220, 1225, 1325,
 /*   340 */  1200, 1284, 1249, 1207, 1238, 1289, 1327, 1245, 1257, 1293,
 /*   350 */  1274, 1295, 1296, 1298, 1279, 1258, 1294, 1262, 1302, 1283,
 /*   360 */  1292, 1306, 1308, 1309, 1310, 1254, 1311, 1312, 1314, 1315,
 /*   370 */  1259, 1317, 1318, 1316, 1247, 1321, 1255, 1320, 1263, 1323,
 /*   380 */  1266, 1322, 1328, 1329, 1320, 1330, 1278, 1324, 1331, 1333,
 /*   390 */  1326, 1334, 1336, 1285, 1335, 1337, 1339, 1297, 1335, 1340,
 /*   400 */  1342, 1343, 1345, 1346, 1268, 1347, 1349, 1319, 1271, 1356,
 /*   410 */  1362, 1395, 1397,
};
#define YY_REDUCE_USE_DFLT (-136)
#define YY_REDUCE_COUNT (269)
#define YY_REDUCE_MIN   (-135)
#define YY_REDUCE_MAX   (1119)
static const short yy_reduce_ofst[] = {
 /*     0 */   -20,  452,   46,  404,  495,  530,  592,  646,  648,  122,
 /*    10 */   360,  651,  653,  662,  669,  671,  678,  537,   48,  167,
 /*    20 */    13,  263,  378,  680,  687,  694,  711,  716,  719,  727,
 /*    30 */   736,  741,  743,  747,  757,  764,  766,  772,  774,  781,
 /*    40 */   789,  797,  804,  806,  812,  814,  820,  822,  831,  837,
 /*    50 */   846,  851,  854,  860,  869,  877,  879,  885,  893,  896,
 /*    60 */   900,  904,  357,  376,  160,  160,  441,  561,  876,  331,
 /*    70 */   331,  331,  331,  331,  331,  331,  331,  331,  331,  331,
 /*    80 */   331,  331,  331,  331,  331,  331,  331,  331,  331,  331,
 /*    90 */   331,  331,  331,  331,  331,  331,  331,  331,  331,  331,
 /*   100 */   331,  331,  331,  331,  331,  666,  500,  580,  627,  331,
 /*   110 */   331,  331,  331, -135,  458,  286,  525,  311,  358,  415,
 /*   120 */    -1,   61,  494,  497,  795,  817,  808,  813,  925,  927,
 /*   130 */   938,  942,  946,  140,  947,  593,  368,  705,  629,  685,
 /*   140 */   713,  405,  763,  823,  815,  880,  914,  915,  917,  928,
 /*   150 */   932,  936,  528,  907,  143,  173,  214,  110,  155,  235,
 /*   160 */   268,  267,  302,  338,  354,  392,  401,  512,  686,  454,
 /*   170 */   477,  721,  709,  235,  765,  606,  742,  798,  856,  887,
 /*   180 */   894,  975,  995,  950,  960,  962, 1021, 1027,  944,  979,
 /*   190 */  1029,  948, 1030, 1031, 1034, 1035, 1036, 1039, 1017, 1043,
 /*   200 */  1023, 1044, 1045,  981, 1046,  970, 1047, 1048, 1002,  686,
 /*   210 */  1008, 1009, 1051, 1052, 1053, 1054, 1040, 1049,  997, 1032,
 /*   220 */  1020, 1050, 1055, 1056, 1057,  984,  989, 1067, 1058, 1010,
 /*   230 */  1061, 1062, 1068, 1059, 1070, 1071, 1060, 1063, 1069, 1064,
 /*   240 */  1072, 1065, 1079, 1077, 1073, 1085, 1086, 1066, 1074, 1076,
 /*   250 */  1080, 1081, 1083, 1084, 1087, 1028, 1090, 1091, 1093, 1016,
 /*   260 */  1096, 1101, 1105, 1102, 1098, 1113, 1117, 1119, 1109, 1112,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1163, 1151, 1151, 1151, 1094, 1094, 1094, 1094, 1094,  923,
 /*    10 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1093, 1151,  923,
 /*    20 */   991, 1018, 1018, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*    30 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*    40 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*    50 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*    60 */  1198, 1198, 1198, 1198,  923,  923, 1198, 1151,  995, 1024,
 /*    70 */  1198, 1198, 1095, 1096, 1198, 1198, 1198, 1127, 1035, 1034,
 /*    80 */  1033, 1032, 1005, 1030, 1022, 1026, 1095, 1089, 1090, 1088,
 /*    90 */  1092, 1096, 1198, 1025, 1060, 1073, 1059, 1069, 1079, 1070,
 /*   100 */  1062, 1061, 1063, 1064, 1065, 1198,  942,  942,  942, 1066,
 /*   110 */  1076, 1075, 1074, 1198, 1198, 1198, 1198, 1101, 1198, 1198,
 /*   120 */  1198,  962, 1198, 1198, 1198, 1151, 1198, 1198, 1198, 1198,
 /*   130 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   140 */  1198,  962, 1198, 1198, 1198, 1198, 1198, 1151, 1151, 1151,
 /*   150 */  1151, 1151,  995,  986, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   160 */   991, 1198, 1198, 1198, 1198, 1198, 1121, 1198, 1198,  991,
 /*   170 */   991,  991, 1198,  993, 1198,  975,  985, 1198, 1198, 1198,
 /*   180 */  1198, 1198, 1113, 1029, 1007, 1007, 1198, 1198, 1196, 1029,
 /*   190 */  1198, 1196, 1198, 1198, 1198, 1198, 1198, 1198,  936, 1198,
 /*   200 */  1018, 1198, 1198, 1007, 1198, 1091, 1198, 1198,  985, 1198,
 /*   210 */   992,  985, 1198, 1198, 1198, 1198,  948, 1102, 1040,  965,
 /*   220 */  1029,  972,  972,  972,  972, 1126, 1125,  917, 1029, 1040,
 /*   230 */   965,  965,  917, 1102,  917,  917,  948, 1102,  956,  939,
 /*   240 */   938,  948, 1102,  936,  956,  963,  963, 1011, 1006, 1011,
 /*   250 */  1006, 1011, 1006, 1011, 1006, 1097, 1198, 1102, 1102, 1198,
 /*   260 */  1023, 1012, 1021, 1019, 1029, 1198, 1166, 1166, 1173, 1173,
 /*   270 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   280 */  1107, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   290 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1046, 1198, 1198,
 /*   300 */   907, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1143,
 /*   310 */  1198, 1198, 1189, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   320 */  1198, 1198, 1198, 1124, 1123, 1198, 1198, 1198, 1198, 1198,
 /*   330 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1195, 1198,
 /*   340 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   350 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
 /*   360 */  1198, 1198, 1198, 1198, 1198,  977, 1198, 1198, 1198, 1179,
 /*   370 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1020, 1198, 1013,
 /*   380 */  1198, 1198, 1198, 1198, 1186, 1198, 1198, 1198, 1198, 1198,
 /*   390 */  1198, 1198, 1198, 1198, 1153, 1198, 1198, 1198, 1152, 1198,
 /*   400 */  1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,  911,
 /*   410 */  1198, 1198, 1198,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   46,  /*      QUERY => ID */
   46,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   46,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   46,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   46,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   46,  /*      ABORT => ID */
   46,  /*     ACTION => ID */
   46,  /*        ADD => ID */
   46,  /*      AFTER => ID */
   46,  /* AUTOINCREMENT => ID */
   46,  /*     BEFORE => ID */
   46,  /*    CASCADE => ID */
   46,  /*   CONFLICT => ID */
   46,  /*   DEFERRED => ID */
   46,  /*        END => ID */
   46,  /*       FAIL => ID */
   46,  /*     IGNORE => ID */
   46,  /*  INITIALLY => ID */
   46,  /*    INSTEAD => ID */
   46,  /*         NO => ID */
   46,  /*        KEY => ID */
   46,  /*     OFFSET => ID */
   46,  /*      RAISE => ID */
   46,  /*    REPLACE => ID */
   46,  /*   RESTRICT => ID */
   46,  /*     RENAME => ID */
   46,  /*   CTIME_KW => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "ACTION",        "ADD",           "AFTER",       
  "AUTOINCREMENT",  "BEFORE",        "CASCADE",       "CONFLICT",    
  "DEFERRED",      "END",           "FAIL",          "IGNORE",      
  "INITIALLY",     "INSTEAD",       "NO",            "KEY",         
  "OFFSET",        "RAISE",         "REPLACE",       "RESTRICT",    
  "RENAME",        "CTIME_KW",      "ANY",           "STRING",      
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "UPDATE",        "DELETE",        "SIMPLE",      
  "PARTIAL",       "FULL",          "SET",           "DEFERRABLE",  
  "IMMEDIATE",     "FOREIGN",       "DROP",          "VIEW",        
  "AS",            "UNION",         "ALL",           "EXCEPT",      
  "INTERSECT",     "SELECT",        "VALUES",        "DISTINCT",    
  "DOT",           "FROM",          "JOIN_KW",       "JOIN",        
  "BY",            "USING",         "ORDER",         "ASC",         
  "DESC",          "GROUP",         "HAVING",        "LIMIT",       
  "TRUNCATE",      "WHERE",         "INTO",          "INSERT",      
  "FLOAT",         "BLOB",          "INTEGER",       "VARIABLE",    
  "CAST",          "CHAR",          "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "PRAGMA",      
  "BEGIN",         "TRIGGER",       "OF",            "FOR",         
  "EACH",          "ROW",           "ALTER",         "WITH",        
  "RECURSIVE",     "TEXT",          "SCALAR",        "VARCHAR",     
  "FLOAT_KW",      "REAL",          "DOUBLE",        "INT",         
  "INTEGER_KW",    "error",         "input",         "ecmd",        
  "explain",       "cmdx",          "cmd",           "savepoint_opt",
  "nm",            "create_table",  "create_table_args",  "createkw",    
  "ifnotexists",   "columnlist",    "tcons",         "columnname",  
  "carglist",      "typedef",       "ccons",         "cconsname",   
  "term",          "expr",          "onconf",        "sortorder",   
  "autoinc",       "check_constraint_def",  "eidlist_opt",   "matcharg",    
  "refargs",       "defer_subclause",  "refact_update",  "refact_delete",
  "refact",        "init_deferred_pred_opt",  "sortlist",      "eidlist",     
  "defer_subclause_opt",  "index_onconf",  "orconf",        "resolvetype", 
  "raisetype",     "ifexists",      "fullname",      "select",      
  "selectnowith",  "oneselect",     "with",          "multiselect_op",
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "values",        "nexprlist",     "exprlist",      "sclp",        
  "as",            "seltablist",    "stl_prefix",    "joinop",      
  "indexed_opt",   "on_opt",        "using_opt",     "join_nm",     
  "idlist",        "setlist",       "insert_cmd",    "idlist_opt",  
  "type_func",     "likeop",        "between_op",    "in_op",       
  "paren_exprlist",  "case_operand",  "case_exprlist",  "case_else",   
  "uniqueflag",    "nmnum",         "minus_num",     "plus_num",    
  "trigger_decl",  "trigger_cmd_list",  "trigger_time",  "trigger_event",
  "foreach_clause",  "when_clause",   "trigger_cmd",   "trnm",        
  "tridxby",       "alter_table_start",  "alter_add_constraint",  "unique_spec", 
  "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "create_table_args ::= LP columnlist RP",
 /*  15 */ "columnname ::= nm typedef",
 /*  16 */ "nm ::= ID|INDEXED",
 /*  17 */ "cconsname ::= CONSTRAINT nm",
 /*  18 */ "cconsname ::=",
 /*  19 */ "ccons ::= DEFAULT term",
 /*  20 */ "ccons ::= DEFAULT LP expr RP",
 /*  21 */ "ccons ::= DEFAULT PLUS term",
 /*  22 */ "ccons ::= DEFAULT MINUS term",
 /*  23 */ "ccons ::= NULL onconf",
 /*  24 */ "ccons ::= NOT NULL onconf",
 /*  25 */ "ccons ::= cconsname PRIMARY KEY sortorder autoinc",
 /*  26 */ "ccons ::= cconsname UNIQUE",
 /*  27 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  28 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  29 */ "ccons ::= defer_subclause",
 /*  30 */ "ccons ::= COLLATE ID|INDEXED",
 /*  31 */ "autoinc ::=",
 /*  32 */ "autoinc ::= AUTOINCR",
 /*  33 */ "refargs ::= refact_update",
 /*  34 */ "refargs ::= refact_delete",
 /*  35 */ "refargs ::= refact_delete refact_update",
 /*  36 */ "refargs ::= refact_update refact_delete",
 /*  37 */ "refargs ::=",
 /*  38 */ "refact_update ::= ON UPDATE refact",
 /*  39 */ "refact_delete ::= ON DELETE refact",
 /*  40 */ "matcharg ::= MATCH SIMPLE",
 /*  41 */ "matcharg ::= MATCH PARTIAL",
 /*  42 */ "matcharg ::= MATCH FULL",
 /*  43 */ "matcharg ::=",
 /*  44 */ "refact ::= SET NULL",
 /*  45 */ "refact ::= SET DEFAULT",
 /*  46 */ "refact ::= CASCADE",
 /*  47 */ "refact ::= RESTRICT",
 /*  48 */ "refact ::= NO ACTION",
 /*  49 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  50 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  51 */ "init_deferred_pred_opt ::=",
 /*  52 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  53 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  54 */ "tcons ::= cconsname PRIMARY KEY LP sortlist autoinc RP",
 /*  55 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  56 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  57 */ "defer_subclause_opt ::=",
 /*  58 */ "onconf ::=",
 /*  59 */ "onconf ::= ON CONFLICT resolvetype",
 /*  60 */ "orconf ::=",
 /*  61 */ "orconf ::= OR resolvetype",
 /*  62 */ "resolvetype ::= IGNORE",
 /*  63 */ "resolvetype ::= REPLACE",
 /*  64 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  65 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  66 */ "ifexists ::= IF EXISTS",
 /*  67 */ "ifexists ::=",
 /*  68 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  69 */ "cmd ::= select",
 /*  70 */ "select ::= with selectnowith",
 /*  71 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  72 */ "multiselect_op ::= UNION",
 /*  73 */ "multiselect_op ::= UNION ALL",
 /*  74 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  75 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  76 */ "values ::= VALUES LP nexprlist RP",
 /*  77 */ "values ::= values COMMA LP exprlist RP",
 /*  78 */ "distinct ::= DISTINCT",
 /*  79 */ "distinct ::= ALL",
 /*  80 */ "distinct ::=",
 /*  81 */ "sclp ::=",
 /*  82 */ "selcollist ::= sclp expr as",
 /*  83 */ "selcollist ::= sclp STAR",
 /*  84 */ "selcollist ::= sclp nm DOT STAR",
 /*  85 */ "as ::= AS nm",
 /*  86 */ "as ::=",
 /*  87 */ "from ::=",
 /*  88 */ "from ::= FROM seltablist",
 /*  89 */ "stl_prefix ::= seltablist joinop",
 /*  90 */ "stl_prefix ::=",
 /*  91 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  92 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  93 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  95 */ "fullname ::= nm",
 /*  96 */ "joinop ::= COMMA|JOIN",
 /*  97 */ "joinop ::= JOIN_KW JOIN",
 /*  98 */ "joinop ::= JOIN_KW join_nm JOIN",
 /*  99 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 100 */ "on_opt ::= ON expr",
 /* 101 */ "on_opt ::=",
 /* 102 */ "indexed_opt ::=",
 /* 103 */ "indexed_opt ::= INDEXED BY nm",
 /* 104 */ "indexed_opt ::= NOT INDEXED",
 /* 105 */ "using_opt ::= USING LP idlist RP",
 /* 106 */ "using_opt ::=",
 /* 107 */ "orderby_opt ::=",
 /* 108 */ "orderby_opt ::= ORDER BY sortlist",
 /* 109 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 110 */ "sortlist ::= expr sortorder",
 /* 111 */ "sortorder ::= ASC",
 /* 112 */ "sortorder ::= DESC",
 /* 113 */ "sortorder ::=",
 /* 114 */ "groupby_opt ::=",
 /* 115 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 116 */ "having_opt ::=",
 /* 117 */ "having_opt ::= HAVING expr",
 /* 118 */ "limit_opt ::=",
 /* 119 */ "limit_opt ::= LIMIT expr",
 /* 120 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 121 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 122 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 123 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 124 */ "where_opt ::=",
 /* 125 */ "where_opt ::= WHERE expr",
 /* 126 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 127 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 128 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 129 */ "setlist ::= nm EQ expr",
 /* 130 */ "setlist ::= LP idlist RP EQ expr",
 /* 131 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 132 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 133 */ "insert_cmd ::= INSERT orconf",
 /* 134 */ "insert_cmd ::= REPLACE",
 /* 135 */ "idlist_opt ::=",
 /* 136 */ "idlist_opt ::= LP idlist RP",
 /* 137 */ "idlist ::= idlist COMMA nm",
 /* 138 */ "idlist ::= nm",
 /* 139 */ "expr ::= LP expr RP",
 /* 140 */ "term ::= NULL",
 /* 141 */ "expr ::= ID|INDEXED",
 /* 142 */ "expr ::= JOIN_KW",
 /* 143 */ "expr ::= nm DOT nm",
 /* 144 */ "term ::= FLOAT|BLOB",
 /* 145 */ "term ::= STRING",
 /* 146 */ "term ::= INTEGER",
 /* 147 */ "expr ::= VARIABLE",
 /* 148 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 149 */ "expr ::= CAST LP expr AS typedef RP",
 /* 150 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 151 */ "expr ::= type_func LP distinct exprlist RP",
 /* 152 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 153 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 154 */ "expr ::= expr AND expr",
 /* 155 */ "expr ::= expr OR expr",
 /* 156 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 157 */ "expr ::= expr EQ|NE expr",
 /* 158 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 159 */ "expr ::= expr PLUS|MINUS expr",
 /* 160 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 161 */ "expr ::= expr CONCAT expr",
 /* 162 */ "likeop ::= LIKE_KW|MATCH",
 /* 163 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 164 */ "expr ::= expr likeop expr",
 /* 165 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 166 */ "expr ::= expr IS NULL",
 /* 167 */ "expr ::= expr IS NOT NULL",
 /* 168 */ "expr ::= NOT expr",
 /* 169 */ "expr ::= BITNOT expr",
 /* 170 */ "expr ::= MINUS expr",
 /* 171 */ "expr ::= PLUS expr",
 /* 172 */ "between_op ::= BETWEEN",
 /* 173 */ "between_op ::= NOT BETWEEN",
 /* 174 */ "expr ::= expr between_op expr AND expr",
 /* 175 */ "in_op ::= IN",
 /* 176 */ "in_op ::= NOT IN",
 /* 177 */ "expr ::= expr in_op LP exprlist RP",
 /* 178 */ "expr ::= LP select RP",
 /* 179 */ "expr ::= expr in_op LP select RP",
 /* 180 */ "expr ::= expr in_op nm paren_exprlist",
 /* 181 */ "expr ::= EXISTS LP select RP",
 /* 182 */ "expr ::= CASE case_operand case_exprlist case_else END",
 /* 183 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 184 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 185 */ "case_else ::= ELSE expr",
 /* 186 */ "case_else ::=",
 /* 187 */ "case_operand ::= expr",
 /* 188 */ "case_operand ::=",
 /* 189 */ "exprlist ::=",
 /* 190 */ "nexprlist ::= nexprlist COMMA expr",
 /* 191 */ "nexprlist ::= expr",
 /* 192 */ "paren_exprlist ::=",
 /* 193 */ "paren_exprlist ::= LP exprlist RP",
 /* 194 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 195 */ "uniqueflag ::= UNIQUE",
 /* 196 */ "uniqueflag ::=",
 /* 197 */ "eidlist_opt ::=",
 /* 198 */ "eidlist_opt ::= LP eidlist RP",
 /* 199 */ "eidlist ::= eidlist COMMA nm",
 /* 200 */ "eidlist ::= nm",
 /* 201 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 202 */ "cmd ::= PRAGMA nm",
 /* 203 */ "cmd ::= PRAGMA nm EQ nmnum",
 /* 204 */ "cmd ::= PRAGMA nm LP nmnum RP",
 /* 205 */ "cmd ::= PRAGMA nm EQ minus_num",
 /* 206 */ "cmd ::= PRAGMA nm LP minus_num RP",
 /* 207 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 208 */ "cmd ::= PRAGMA",
 /* 209 */ "plus_num ::= PLUS INTEGER|FLOAT",
 /* 210 */ "minus_num ::= MINUS INTEGER|FLOAT",
 /* 211 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 212 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 213 */ "trigger_time ::= BEFORE",
 /* 214 */ "trigger_time ::= AFTER",
 /* 215 */ "trigger_time ::= INSTEAD OF",
 /* 216 */ "trigger_time ::=",
 /* 217 */ "trigger_event ::= DELETE|INSERT",
 /* 218 */ "trigger_event ::= UPDATE",
 /* 219 */ "trigger_event ::= UPDATE OF idlist",
 /* 220 */ "foreach_clause ::=",
 /* 221 */ "when_clause ::=",
 /* 222 */ "when_clause ::= WHEN expr",
 /* 223 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 224 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 225 */ "trnm ::= nm DOT nm",
 /* 226 */ "tridxby ::= INDEXED BY nm",
 /* 227 */ "tridxby ::= NOT INDEXED",
 /* 228 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 229 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 230 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 231 */ "trigger_cmd ::= select",
 /* 232 */ "expr ::= RAISE LP IGNORE RP",
 /* 233 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 234 */ "raisetype ::= ROLLBACK",
 /* 235 */ "raisetype ::= ABORT",
 /* 236 */ "raisetype ::= FAIL",
 /* 237 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 238 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 239 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 240 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 241 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 242 */ "unique_spec ::= UNIQUE",
 /* 243 */ "unique_spec ::= PRIMARY KEY",
 /* 244 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 245 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 246 */ "with ::=",
 /* 247 */ "with ::= WITH wqlist",
 /* 248 */ "with ::= WITH RECURSIVE wqlist",
 /* 249 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 250 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 251 */ "typedef ::= TEXT",
 /* 252 */ "typedef ::= SCALAR",
 /* 253 */ "char_len ::= LP INTEGER RP",
 /* 254 */ "typedef ::= VARCHAR char_len",
 /* 255 */ "number_typedef ::= FLOAT_KW|REAL|DOUBLE",
 /* 256 */ "number_typedef ::= INT|INTEGER_KW",
 /* 257 */ "input ::= ecmd",
 /* 258 */ "explain ::=",
 /* 259 */ "cmdx ::= cmd",
 /* 260 */ "savepoint_opt ::= SAVEPOINT",
 /* 261 */ "savepoint_opt ::=",
 /* 262 */ "cmd ::= create_table create_table_args",
 /* 263 */ "columnlist ::= columnlist COMMA tcons",
 /* 264 */ "columnlist ::= columnlist COMMA columnname carglist",
 /* 265 */ "columnlist ::= columnname carglist",
 /* 266 */ "columnlist ::= tcons",
 /* 267 */ "carglist ::= carglist ccons",
 /* 268 */ "carglist ::=",
 /* 269 */ "ccons ::= check_constraint_def",
 /* 270 */ "tcons ::= check_constraint_def",
 /* 271 */ "defer_subclause_opt ::= defer_subclause",
 /* 272 */ "resolvetype ::= raisetype",
 /* 273 */ "selectnowith ::= oneselect",
 /* 274 */ "oneselect ::= values",
 /* 275 */ "sclp ::= selcollist COMMA",
 /* 276 */ "as ::= ID|STRING",
 /* 277 */ "join_nm ::= ID|INDEXED",
 /* 278 */ "join_nm ::= JOIN_KW",
 /* 279 */ "expr ::= term",
 /* 280 */ "type_func ::= CHAR",
 /* 281 */ "exprlist ::= nexprlist",
 /* 282 */ "nmnum ::= plus_num",
 /* 283 */ "nmnum ::= STRING",
 /* 284 */ "nmnum ::= nm",
 /* 285 */ "nmnum ::= ON",
 /* 286 */ "nmnum ::= DELETE",
 /* 287 */ "nmnum ::= DEFAULT",
 /* 288 */ "plus_num ::= INTEGER|FLOAT",
 /* 289 */ "foreach_clause ::= FOR EACH ROW",
 /* 290 */ "trnm ::= nm",
 /* 291 */ "tridxby ::=",
 /* 292 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 164: /* term */
    case 165: /* expr */
{
#line 879 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy190).pExpr, false);
#line 1496 "parse.c"
}
      break;
    case 170: /* eidlist_opt */
    case 178: /* sortlist */
    case 179: /* eidlist */
    case 193: /* selcollist */
    case 196: /* groupby_opt */
    case 198: /* orderby_opt */
    case 201: /* nexprlist */
    case 202: /* exprlist */
    case 203: /* sclp */
    case 213: /* setlist */
    case 220: /* paren_exprlist */
    case 222: /* case_exprlist */
{
#line 1377 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy412));
#line 1514 "parse.c"
}
      break;
    case 186: /* fullname */
    case 194: /* from */
    case 205: /* seltablist */
    case 206: /* stl_prefix */
{
#line 664 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy367));
#line 1524 "parse.c"
}
      break;
    case 187: /* select */
    case 188: /* selectnowith */
    case 189: /* oneselect */
    case 200: /* values */
{
#line 426 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy99));
#line 1534 "parse.c"
}
      break;
    case 190: /* with */
    case 240: /* wqlist */
{
#line 1655 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy91));
#line 1542 "parse.c"
}
      break;
    case 195: /* where_opt */
    case 197: /* having_opt */
    case 209: /* on_opt */
    case 221: /* case_operand */
    case 223: /* case_else */
    case 233: /* when_clause */
{
#line 788 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy44), false);
#line 1554 "parse.c"
}
      break;
    case 210: /* using_opt */
    case 212: /* idlist */
    case 215: /* idlist_opt */
{
#line 707 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy258));
#line 1563 "parse.c"
}
      break;
    case 229: /* trigger_cmd_list */
    case 234: /* trigger_cmd */
{
#line 1492 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy203));
#line 1571 "parse.c"
}
      break;
    case 231: /* trigger_event */
{
#line 1474 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy234).b);
#line 1578 "parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 43 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1754 "parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 147, 3 },
  { 147, 1 },
  { 148, 1 },
  { 148, 3 },
  { 150, 2 },
  { 150, 1 },
  { 150, 1 },
  { 150, 2 },
  { 150, 3 },
  { 150, 4 },
  { 153, 4 },
  { 155, 1 },
  { 156, 0 },
  { 156, 3 },
  { 154, 3 },
  { 159, 2 },
  { 152, 1 },
  { 163, 2 },
  { 163, 0 },
  { 162, 2 },
  { 162, 4 },
  { 162, 3 },
  { 162, 3 },
  { 162, 2 },
  { 162, 3 },
  { 162, 5 },
  { 162, 2 },
  { 169, 5 },
  { 162, 6 },
  { 162, 1 },
  { 162, 2 },
  { 168, 0 },
  { 168, 1 },
  { 172, 1 },
  { 172, 1 },
  { 172, 2 },
  { 172, 2 },
  { 172, 0 },
  { 174, 3 },
  { 175, 3 },
  { 171, 2 },
  { 171, 2 },
  { 171, 2 },
  { 171, 0 },
  { 176, 2 },
  { 176, 2 },
  { 176, 1 },
  { 176, 1 },
  { 176, 2 },
  { 173, 3 },
  { 173, 2 },
  { 177, 0 },
  { 177, 2 },
  { 177, 2 },
  { 158, 7 },
  { 158, 5 },
  { 158, 12 },
  { 180, 0 },
  { 166, 0 },
  { 166, 3 },
  { 182, 0 },
  { 182, 2 },
  { 183, 1 },
  { 183, 1 },
  { 150, 4 },
  { 150, 4 },
  { 185, 2 },
  { 185, 0 },
  { 150, 7 },
  { 150, 1 },
  { 187, 2 },
  { 188, 3 },
  { 191, 1 },
  { 191, 2 },
  { 191, 1 },
  { 189, 9 },
  { 200, 4 },
  { 200, 5 },
  { 192, 1 },
  { 192, 1 },
  { 192, 0 },
  { 203, 0 },
  { 193, 3 },
  { 193, 2 },
  { 193, 4 },
  { 204, 2 },
  { 204, 0 },
  { 194, 0 },
  { 194, 2 },
  { 206, 2 },
  { 206, 0 },
  { 205, 6 },
  { 205, 8 },
  { 205, 7 },
  { 205, 7 },
  { 186, 1 },
  { 207, 1 },
  { 207, 2 },
  { 207, 3 },
  { 207, 4 },
  { 209, 2 },
  { 209, 0 },
  { 208, 0 },
  { 208, 3 },
  { 208, 2 },
  { 210, 4 },
  { 210, 0 },
  { 198, 0 },
  { 198, 3 },
  { 178, 4 },
  { 178, 2 },
  { 167, 1 },
  { 167, 1 },
  { 167, 0 },
  { 196, 0 },
  { 196, 3 },
  { 197, 0 },
  { 197, 2 },
  { 199, 0 },
  { 199, 2 },
  { 199, 4 },
  { 199, 4 },
  { 150, 6 },
  { 150, 3 },
  { 195, 0 },
  { 195, 2 },
  { 150, 8 },
  { 213, 5 },
  { 213, 7 },
  { 213, 3 },
  { 213, 5 },
  { 150, 6 },
  { 150, 7 },
  { 214, 2 },
  { 214, 1 },
  { 215, 0 },
  { 215, 3 },
  { 212, 3 },
  { 212, 1 },
  { 165, 3 },
  { 164, 1 },
  { 165, 1 },
  { 165, 1 },
  { 165, 3 },
  { 164, 1 },
  { 164, 1 },
  { 164, 1 },
  { 165, 1 },
  { 165, 3 },
  { 165, 6 },
  { 165, 5 },
  { 165, 5 },
  { 165, 4 },
  { 165, 5 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 165, 3 },
  { 217, 1 },
  { 217, 2 },
  { 165, 3 },
  { 165, 5 },
  { 165, 3 },
  { 165, 4 },
  { 165, 2 },
  { 165, 2 },
  { 165, 2 },
  { 165, 2 },
  { 218, 1 },
  { 218, 2 },
  { 165, 5 },
  { 219, 1 },
  { 219, 2 },
  { 165, 5 },
  { 165, 3 },
  { 165, 5 },
  { 165, 4 },
  { 165, 4 },
  { 165, 5 },
  { 222, 5 },
  { 222, 4 },
  { 223, 2 },
  { 223, 0 },
  { 221, 1 },
  { 221, 0 },
  { 202, 0 },
  { 201, 3 },
  { 201, 1 },
  { 220, 0 },
  { 220, 3 },
  { 150, 10 },
  { 224, 1 },
  { 224, 0 },
  { 170, 0 },
  { 170, 3 },
  { 179, 3 },
  { 179, 1 },
  { 150, 6 },
  { 150, 2 },
  { 150, 4 },
  { 150, 5 },
  { 150, 4 },
  { 150, 5 },
  { 150, 7 },
  { 150, 1 },
  { 227, 2 },
  { 226, 2 },
  { 150, 5 },
  { 228, 9 },
  { 230, 1 },
  { 230, 1 },
  { 230, 2 },
  { 230, 0 },
  { 231, 1 },
  { 231, 1 },
  { 231, 3 },
  { 232, 0 },
  { 233, 0 },
  { 233, 2 },
  { 229, 3 },
  { 229, 2 },
  { 235, 3 },
  { 236, 3 },
  { 236, 2 },
  { 234, 7 },
  { 234, 5 },
  { 234, 5 },
  { 234, 1 },
  { 165, 4 },
  { 165, 6 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 150, 4 },
  { 237, 3 },
  { 238, 4 },
  { 150, 12 },
  { 150, 5 },
  { 239, 1 },
  { 239, 2 },
  { 150, 4 },
  { 150, 6 },
  { 190, 0 },
  { 190, 2 },
  { 190, 3 },
  { 240, 6 },
  { 240, 8 },
  { 161, 1 },
  { 161, 1 },
  { 241, 3 },
  { 161, 2 },
  { 242, 1 },
  { 242, 1 },
  { 146, 1 },
  { 148, 0 },
  { 149, 1 },
  { 151, 1 },
  { 151, 0 },
  { 150, 2 },
  { 157, 3 },
  { 157, 4 },
  { 157, 2 },
  { 157, 1 },
  { 160, 2 },
  { 160, 0 },
  { 162, 1 },
  { 158, 1 },
  { 180, 1 },
  { 183, 1 },
  { 188, 1 },
  { 189, 1 },
  { 203, 2 },
  { 204, 1 },
  { 211, 1 },
  { 211, 1 },
  { 165, 1 },
  { 216, 1 },
  { 202, 1 },
  { 225, 1 },
  { 225, 1 },
  { 225, 1 },
  { 225, 1 },
  { 225, 1 },
  { 225, 1 },
  { 227, 1 },
  { 232, 3 },
  { 235, 1 },
  { 236, 0 },
  { 161, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 115 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2190 "parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 119 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2198 "parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 124 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2203 "parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 125 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2208 "parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 155 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2213 "parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 156 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2218 "parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 157 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2223 "parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 161 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2230 "parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 164 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2237 "parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 167 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2244 "parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 174 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy58);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
}
#line 2252 "parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 178 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2257 "parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 31: /* autoinc ::= */ yytestcase(yyruleno==31);
      case 51: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==51);
      case 57: /* defer_subclause_opt ::= */ yytestcase(yyruleno==57);
      case 67: /* ifexists ::= */ yytestcase(yyruleno==67);
      case 80: /* distinct ::= */ yytestcase(yyruleno==80);
#line 181 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy58 = 0;}
#line 2267 "parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 182 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy58 = 1;}
#line 2272 "parse.c"
        break;
      case 14: /* create_table_args ::= LP columnlist RP */
#line 184 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlEndTable(pParse);
}
#line 2279 "parse.c"
        break;
      case 15: /* columnname ::= nm typedef */
#line 202 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sqlAddColumn(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy438);}
#line 2284 "parse.c"
        break;
      case 16: /* nm ::= ID|INDEXED */
#line 240 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2294 "parse.c"
        break;
      case 17: /* cconsname ::= CONSTRAINT nm */
#line 253 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy415 = yymsp[0].minor.yy0; }
#line 2299 "parse.c"
        break;
      case 18: /* cconsname ::= */
#line 254 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[1].minor.yy415 = Token_nil; }
#line 2304 "parse.c"
        break;
      case 19: /* ccons ::= DEFAULT term */
      case 21: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==21);
#line 255 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy190);}
#line 2310 "parse.c"
        break;
      case 20: /* ccons ::= DEFAULT LP expr RP */
#line 256 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy190);}
#line 2315 "parse.c"
        break;
      case 22: /* ccons ::= DEFAULT MINUS term */
#line 258 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy190.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy190.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2326 "parse.c"
        break;
      case 23: /* ccons ::= NULL onconf */
#line 269 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy58 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy58);
}
#line 2336 "parse.c"
        break;
      case 24: /* ccons ::= NOT NULL onconf */
#line 275 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy58);}
#line 2341 "parse.c"
        break;
      case 25: /* ccons ::= cconsname PRIMARY KEY sortorder autoinc */
#line 276 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  pParse->create_table_def.has_autoinc = yymsp[0].minor.yy58;
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy415, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[-1].minor.yy58, false);
  sqlAddPrimaryKey(pParse);
}
#line 2351 "parse.c"
        break;
      case 26: /* ccons ::= cconsname UNIQUE */
#line 282 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy415, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2361 "parse.c"
        break;
      case 27: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 291 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, &yymsp[-4].minor.yy415, &yymsp[-1].minor.yy190);
  sql_add_check_constraint(pParse);
}
#line 2369 "parse.c"
        break;
      case 28: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 296 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy415, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy412, yymsp[-1].minor.yy58, yymsp[0].minor.yy58,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2378 "parse.c"
        break;
      case 29: /* ccons ::= defer_subclause */
#line 301 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy58);}
#line 2383 "parse.c"
        break;
      case 30: /* ccons ::= COLLATE ID|INDEXED */
#line 302 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2388 "parse.c"
        break;
      case 32: /* autoinc ::= AUTOINCR */
#line 307 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = 1;}
#line 2393 "parse.c"
        break;
      case 33: /* refargs ::= refact_update */
#line 315 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yylhsminor.yy58 = (yymsp[0].minor.yy58 << 8); }
#line 2398 "parse.c"
  yymsp[0].minor.yy58 = yylhsminor.yy58;
        break;
      case 34: /* refargs ::= refact_delete */
#line 316 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yylhsminor.yy58 = yymsp[0].minor.yy58; }
#line 2404 "parse.c"
  yymsp[0].minor.yy58 = yylhsminor.yy58;
        break;
      case 35: /* refargs ::= refact_delete refact_update */
#line 317 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yylhsminor.yy58 = (yymsp[0].minor.yy58 << 8) | (yymsp[-1].minor.yy58) ; }
#line 2410 "parse.c"
  yymsp[-1].minor.yy58 = yylhsminor.yy58;
        break;
      case 36: /* refargs ::= refact_update refact_delete */
#line 318 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yylhsminor.yy58 = (yymsp[-1].minor.yy58 << 8) | (yymsp[0].minor.yy58) ; }
#line 2416 "parse.c"
  yymsp[-1].minor.yy58 = yylhsminor.yy58;
        break;
      case 37: /* refargs ::= */
#line 319 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[1].minor.yy58 = 0; }
#line 2422 "parse.c"
        break;
      case 38: /* refact_update ::= ON UPDATE refact */
      case 39: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==39);
#line 322 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-2].minor.yy58 = yymsp[0].minor.yy58; }
#line 2428 "parse.c"
        break;
      case 40: /* matcharg ::= MATCH SIMPLE */
#line 327 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_MATCH_SIMPLE; }
#line 2433 "parse.c"
        break;
      case 41: /* matcharg ::= MATCH PARTIAL */
#line 328 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_MATCH_PARTIAL; }
#line 2438 "parse.c"
        break;
      case 42: /* matcharg ::= MATCH FULL */
#line 329 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_MATCH_FULL; }
#line 2443 "parse.c"
        break;
      case 43: /* matcharg ::= */
#line 330 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[1].minor.yy58 = FKEY_MATCH_SIMPLE; }
#line 2448 "parse.c"
        break;
      case 44: /* refact ::= SET NULL */
#line 333 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_ACTION_SET_NULL; }
#line 2453 "parse.c"
        break;
      case 45: /* refact ::= SET DEFAULT */
#line 334 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_ACTION_SET_DEFAULT; }
#line 2458 "parse.c"
        break;
      case 46: /* refact ::= CASCADE */
#line 335 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = FKEY_ACTION_CASCADE; }
#line 2463 "parse.c"
        break;
      case 47: /* refact ::= RESTRICT */
#line 336 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = FKEY_ACTION_RESTRICT; }
#line 2468 "parse.c"
        break;
      case 48: /* refact ::= NO ACTION */
#line 337 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = FKEY_NO_ACTION; }
#line 2473 "parse.c"
        break;
      case 49: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 339 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy58 = 0;}
#line 2478 "parse.c"
        break;
      case 50: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 61: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==61);
      case 133: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==133);
#line 340 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy58 = yymsp[0].minor.yy58;}
#line 2485 "parse.c"
        break;
      case 52: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 66: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==66);
      case 173: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==173);
      case 176: /* in_op ::= NOT IN */ yytestcase(yyruleno==176);
#line 343 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy58 = 1;}
#line 2493 "parse.c"
        break;
      case 53: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 344 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy58 = 0;}
#line 2498 "parse.c"
        break;
      case 54: /* tcons ::= cconsname PRIMARY KEY LP sortlist autoinc RP */
#line 346 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  pParse->create_table_def.has_autoinc = yymsp[-1].minor.yy58;
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-6].minor.yy415, yymsp[-2].minor.yy412,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2508 "parse.c"
        break;
      case 55: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 352 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy415, yymsp[-1].minor.yy412,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2518 "parse.c"
        break;
      case 56: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 360 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy415, yymsp[-7].minor.yy412, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy412, yymsp[-2].minor.yy58, yymsp[-1].minor.yy58, yymsp[0].minor.yy58);
  sql_create_foreign_key(pParse);
}
#line 2526 "parse.c"
        break;
      case 58: /* onconf ::= */
#line 375 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy58 = ON_CONFLICT_ACTION_ABORT;}
#line 2531 "parse.c"
        break;
      case 59: /* onconf ::= ON CONFLICT resolvetype */
#line 376 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy58 = yymsp[0].minor.yy58;}
#line 2536 "parse.c"
        break;
      case 60: /* orconf ::= */
#line 377 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy58 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2541 "parse.c"
        break;
      case 62: /* resolvetype ::= IGNORE */
#line 380 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = ON_CONFLICT_ACTION_IGNORE;}
#line 2546 "parse.c"
        break;
      case 63: /* resolvetype ::= REPLACE */
      case 134: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==134);
#line 381 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = ON_CONFLICT_ACTION_REPLACE;}
#line 2552 "parse.c"
        break;
      case 64: /* cmd ::= DROP TABLE ifexists fullname */
#line 386 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy58);
  sql_drop_table(pParse);
}
#line 2561 "parse.c"
        break;
      case 65: /* cmd ::= DROP VIEW ifexists fullname */
#line 392 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy58);
  sql_drop_table(pParse);
}
#line 2570 "parse.c"
        break;
      case 68: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 405 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy412, yymsp[0].minor.yy99, yymsp[-4].minor.yy58);
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy99);
  }
}
#line 2582 "parse.c"
        break;
      case 69: /* cmd ::= select */
#line 416 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy99, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy99);
  sql_select_delete(pParse->db, yymsp[0].minor.yy99);
}
#line 2594 "parse.c"
        break;
      case 70: /* select ::= with selectnowith */
#line 459 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy99;
  if( p ){
    p->pWith = yymsp[-1].minor.yy91;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy91);
  }
  yymsp[-1].minor.yy99 = p; /*A-overwrites-W*/
}
#line 2608 "parse.c"
        break;
      case 71: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 472 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy99;
  Select *pLhs = yymsp[-2].minor.yy99;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy58;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy58!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy99 = pRhs;
}
#line 2634 "parse.c"
        break;
      case 72: /* multiselect_op ::= UNION */
      case 74: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==74);
#line 495 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2640 "parse.c"
        break;
      case 73: /* multiselect_op ::= UNION ALL */
#line 496 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy58 = TK_ALL;}
#line 2645 "parse.c"
        break;
      case 75: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 500 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy112.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy412);
  yymsp[-8].minor.yy99 = sqlSelectNew(pParse,yymsp[-6].minor.yy412,yymsp[-5].minor.yy367,yymsp[-4].minor.yy44,yymsp[-3].minor.yy412,yymsp[-2].minor.yy44,yymsp[-1].minor.yy412,yymsp[-7].minor.yy58,yymsp[0].minor.yy112.pLimit,yymsp[0].minor.yy112.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy99!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2681 "parse.c"
        break;
      case 76: /* values ::= VALUES LP nexprlist RP */
#line 536 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy99 = sqlSelectNew(pParse,yymsp[-1].minor.yy412,0,0,0,0,0,SF_Values,0,0);
}
#line 2688 "parse.c"
        break;
      case 77: /* values ::= values COMMA LP exprlist RP */
#line 539 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy99;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy412,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy99 = pRight;
  }else{
    yymsp[-4].minor.yy99 = pLeft;
  }
}
#line 2704 "parse.c"
        break;
      case 78: /* distinct ::= DISTINCT */
#line 556 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = SF_Distinct;}
#line 2709 "parse.c"
        break;
      case 79: /* distinct ::= ALL */
#line 557 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = SF_All;}
#line 2714 "parse.c"
        break;
      case 81: /* sclp ::= */
      case 107: /* orderby_opt ::= */ yytestcase(yyruleno==107);
      case 114: /* groupby_opt ::= */ yytestcase(yyruleno==114);
      case 189: /* exprlist ::= */ yytestcase(yyruleno==189);
      case 192: /* paren_exprlist ::= */ yytestcase(yyruleno==192);
      case 197: /* eidlist_opt ::= */ yytestcase(yyruleno==197);
#line 570 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy412 = 0;}
#line 2724 "parse.c"
        break;
      case 82: /* selcollist ::= sclp expr as */
#line 571 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy412 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy412, yymsp[-1].minor.yy190.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy412, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy412,&yymsp[-1].minor.yy190);
}
#line 2733 "parse.c"
        break;
      case 83: /* selcollist ::= sclp STAR */
#line 576 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy412 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy412, p);
}
#line 2745 "parse.c"
        break;
      case 84: /* selcollist ::= sclp nm DOT STAR */
#line 584 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy412, pDot);
}
#line 2759 "parse.c"
        break;
      case 85: /* as ::= AS nm */
      case 209: /* plus_num ::= PLUS INTEGER|FLOAT */ yytestcase(yyruleno==209);
      case 210: /* minus_num ::= MINUS INTEGER|FLOAT */ yytestcase(yyruleno==210);
#line 599 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2766 "parse.c"
        break;
      case 86: /* as ::= */
#line 601 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2771 "parse.c"
        break;
      case 87: /* from ::= */
#line 613 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy367));}
#line 2776 "parse.c"
        break;
      case 88: /* from ::= FROM seltablist */
#line 614 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy367 = yymsp[0].minor.yy367;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy367);
}
#line 2784 "parse.c"
        break;
      case 89: /* stl_prefix ::= seltablist joinop */
#line 622 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy367 && yymsp[-1].minor.yy367->nSrc>0) ) yymsp[-1].minor.yy367->a[yymsp[-1].minor.yy367->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy58;
}
#line 2791 "parse.c"
        break;
      case 90: /* stl_prefix ::= */
#line 625 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = 0;}
#line 2796 "parse.c"
        break;
      case 91: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 627 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy367,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy44,yymsp[0].minor.yy258);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy367, &yymsp[-2].minor.yy0);
}
#line 2804 "parse.c"
        break;
      case 92: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 632 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy367,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy44,yymsp[0].minor.yy258);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy367, yymsp[-4].minor.yy412);
}
#line 2812 "parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 637 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy99,yymsp[-1].minor.yy44,yymsp[0].minor.yy258);
}
#line 2819 "parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 641 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy367==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy44==0 && yymsp[0].minor.yy258==0 ){
    yymsp[-6].minor.yy367 = yymsp[-4].minor.yy367;
  }else if( yymsp[-4].minor.yy367->nSrc==1 ){
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy44,yymsp[0].minor.yy258);
    if( yymsp[-6].minor.yy367 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy367->a[yymsp[-6].minor.yy367->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy367->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy367);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy367);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy367,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy44,yymsp[0].minor.yy258);
  }
}
#line 2844 "parse.c"
        break;
      case 95: /* fullname ::= nm */
#line 665 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  /* yylhsminor.yy367-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy367 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy367 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 2856 "parse.c"
  yymsp[0].minor.yy367 = yylhsminor.yy367;
        break;
      case 96: /* joinop ::= COMMA|JOIN */
#line 678 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = JT_INNER; }
#line 2862 "parse.c"
        break;
      case 97: /* joinop ::= JOIN_KW JOIN */
#line 680 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy58 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 2867 "parse.c"
        break;
      case 98: /* joinop ::= JOIN_KW join_nm JOIN */
#line 682 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy58 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 2872 "parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 684 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-3].minor.yy58 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 2877 "parse.c"
        break;
      case 100: /* on_opt ::= ON expr */
      case 117: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==117);
      case 125: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==125);
      case 185: /* case_else ::= ELSE expr */ yytestcase(yyruleno==185);
#line 688 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy44 = yymsp[0].minor.yy190.pExpr;}
#line 2885 "parse.c"
        break;
      case 101: /* on_opt ::= */
      case 116: /* having_opt ::= */ yytestcase(yyruleno==116);
      case 124: /* where_opt ::= */ yytestcase(yyruleno==124);
      case 186: /* case_else ::= */ yytestcase(yyruleno==186);
      case 188: /* case_operand ::= */ yytestcase(yyruleno==188);
#line 689 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy44 = 0;}
#line 2894 "parse.c"
        break;
      case 102: /* indexed_opt ::= */
#line 702 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 2899 "parse.c"
        break;
      case 103: /* indexed_opt ::= INDEXED BY nm */
#line 703 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 2904 "parse.c"
        break;
      case 104: /* indexed_opt ::= NOT INDEXED */
#line 704 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 2909 "parse.c"
        break;
      case 105: /* using_opt ::= USING LP idlist RP */
#line 708 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-3].minor.yy258 = yymsp[-1].minor.yy258;}
#line 2914 "parse.c"
        break;
      case 106: /* using_opt ::= */
      case 135: /* idlist_opt ::= */ yytestcase(yyruleno==135);
#line 709 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy258 = 0;}
#line 2920 "parse.c"
        break;
      case 108: /* orderby_opt ::= ORDER BY sortlist */
      case 115: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==115);
#line 723 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy412 = yymsp[0].minor.yy412;}
#line 2926 "parse.c"
        break;
      case 109: /* sortlist ::= sortlist COMMA expr sortorder */
#line 724 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy412,yymsp[-1].minor.yy190.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy412,yymsp[0].minor.yy58);
}
#line 2934 "parse.c"
        break;
      case 110: /* sortlist ::= expr sortorder */
#line 728 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  /* yylhsminor.yy412-overwrites-yymsp[-1].minor.yy190. */
  yylhsminor.yy412 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy190.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy412,yymsp[0].minor.yy58);
}
#line 2943 "parse.c"
  yymsp[-1].minor.yy412 = yylhsminor.yy412;
        break;
      case 111: /* sortorder ::= ASC */
#line 736 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = SORT_ORDER_ASC;}
#line 2949 "parse.c"
        break;
      case 112: /* sortorder ::= DESC */
#line 737 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = SORT_ORDER_DESC;}
#line 2954 "parse.c"
        break;
      case 113: /* sortorder ::= */
#line 738 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy58 = SORT_ORDER_UNDEF;}
#line 2959 "parse.c"
        break;
      case 118: /* limit_opt ::= */
#line 763 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy112.pLimit = 0; yymsp[1].minor.yy112.pOffset = 0;}
#line 2964 "parse.c"
        break;
      case 119: /* limit_opt ::= LIMIT expr */
#line 764 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy112.pLimit = yymsp[0].minor.yy190.pExpr; yymsp[-1].minor.yy112.pOffset = 0;}
#line 2969 "parse.c"
        break;
      case 120: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 766 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-3].minor.yy112.pLimit = yymsp[-2].minor.yy190.pExpr; yymsp[-3].minor.yy112.pOffset = yymsp[0].minor.yy190.pExpr;}
#line 2974 "parse.c"
        break;
      case 121: /* limit_opt ::= LIMIT expr COMMA expr */
#line 768 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-3].minor.yy112.pOffset = yymsp[-2].minor.yy190.pExpr; yymsp[-3].minor.yy112.pLimit = yymsp[0].minor.yy190.pExpr;}
#line 2979 "parse.c"
        break;
      case 122: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 772 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy367, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy367,yymsp[0].minor.yy44);
}
#line 2991 "parse.c"
        break;
      case 123: /* cmd ::= TRUNCATE TABLE fullname */
#line 783 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sql_table_truncate(pParse, yymsp[0].minor.yy367);
}
#line 2998 "parse.c"
        break;
      case 126: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 796 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy367, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy412 != NULL && yymsp[-1].minor.yy412->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy412->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy367,yymsp[-1].minor.yy412,yymsp[0].minor.yy44,yymsp[-5].minor.yy58);
}
#line 3015 "parse.c"
        break;
      case 127: /* setlist ::= setlist COMMA nm EQ expr */
#line 813 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy412 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy412, yymsp[0].minor.yy190.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy412, &yymsp[-2].minor.yy0, 1);
}
#line 3023 "parse.c"
        break;
      case 128: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 817 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy412 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy412, yymsp[-3].minor.yy258, yymsp[0].minor.yy190.pExpr);
}
#line 3030 "parse.c"
        break;
      case 129: /* setlist ::= nm EQ expr */
#line 820 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yylhsminor.yy412 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy190.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy412, &yymsp[-2].minor.yy0, 1);
}
#line 3038 "parse.c"
  yymsp[-2].minor.yy412 = yylhsminor.yy412;
        break;
      case 130: /* setlist ::= LP idlist RP EQ expr */
#line 824 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy412 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy258, yymsp[0].minor.yy190.pExpr);
}
#line 3046 "parse.c"
        break;
      case 131: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 830 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy367, yymsp[0].minor.yy99, yymsp[-1].minor.yy258, yymsp[-4].minor.yy58);
}
#line 3057 "parse.c"
        break;
      case 132: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 838 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy367, 0, yymsp[-2].minor.yy258, yymsp[-5].minor.yy58);
}
#line 3068 "parse.c"
        break;
      case 136: /* idlist_opt ::= LP idlist RP */
#line 856 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy258 = yymsp[-1].minor.yy258;}
#line 3073 "parse.c"
        break;
      case 137: /* idlist ::= idlist COMMA nm */
#line 857 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy258 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy258,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy258 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3084 "parse.c"
        break;
      case 138: /* idlist ::= nm */
#line 864 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  /* yylhsminor.yy258-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy258 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy258 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3096 "parse.c"
  yymsp[0].minor.yy258 = yylhsminor.yy258;
        break;
      case 139: /* expr ::= LP expr RP */
#line 962 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy190,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy190.pExpr = yymsp[-1].minor.yy190.pExpr;}
#line 3102 "parse.c"
        break;
      case 140: /* term ::= NULL */
      case 144: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==144);
      case 145: /* term ::= STRING */ yytestcase(yyruleno==145);
#line 963 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy190,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3109 "parse.c"
        break;
      case 141: /* expr ::= ID|INDEXED */
      case 142: /* expr ::= JOIN_KW */ yytestcase(yyruleno==142);
#line 964 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy190,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3115 "parse.c"
        break;
      case 143: /* expr ::= nm DOT nm */
#line 966 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy190,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy190.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3134 "parse.c"
        break;
      case 146: /* term ::= INTEGER */
#line 983 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yylhsminor.yy190.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy190.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy190.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy190.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy190.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy190.pExpr ) yylhsminor.yy190.pExpr->flags |= EP_Leaf;
}
#line 3149 "parse.c"
  yymsp[0].minor.yy190 = yylhsminor.yy190;
        break;
      case 147: /* expr ::= VARIABLE */
#line 994 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy190, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC,
             "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy190.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy190, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy190.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy190.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy190, &t, &t);
    diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy190.pExpr = NULL;
  }
}
#line 3179 "parse.c"
  yymsp[0].minor.yy190 = yylhsminor.yy190;
        break;
      case 148: /* expr ::= expr COLLATE ID|INDEXED */
#line 1019 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy190.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy190.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy190.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3188 "parse.c"
        break;
      case 149: /* expr ::= CAST LP expr AS typedef RP */
#line 1024 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy190,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy190.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy190.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy190.pExpr->type = yymsp[-1].minor.yy438.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy190.pExpr, yymsp[-3].minor.yy190.pExpr, 0);
}
#line 3202 "parse.c"
        break;
      case 150: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 151: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==151);
#line 1035 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy412 && yymsp[-1].minor.yy412->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy412->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy190.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy412, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy190,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy58==SF_Distinct && yylhsminor.yy190.pExpr ){
    yylhsminor.yy190.pExpr->flags |= EP_Distinct;
  }
}
#line 3221 "parse.c"
  yymsp[-4].minor.yy190 = yylhsminor.yy190;
        break;
      case 152: /* expr ::= ID|INDEXED LP STAR RP */
#line 1070 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yylhsminor.yy190.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy190,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3230 "parse.c"
  yymsp[-3].minor.yy190 = yylhsminor.yy190;
        break;
      case 153: /* expr ::= LP nexprlist COMMA expr RP */
#line 1105 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy412, yymsp[-1].minor.yy190.pExpr);
  yylhsminor.yy190.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy190.pExpr ){
    yylhsminor.yy190.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy190, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3245 "parse.c"
  yymsp[-4].minor.yy190 = yylhsminor.yy190;
        break;
      case 154: /* expr ::= expr AND expr */
      case 155: /* expr ::= expr OR expr */ yytestcase(yyruleno==155);
      case 156: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==156);
      case 157: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==157);
      case 158: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==158);
      case 159: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==159);
      case 160: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==160);
      case 161: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==161);
#line 1116 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy190,&yymsp[0].minor.yy190);}
#line 3258 "parse.c"
        break;
      case 162: /* likeop ::= LIKE_KW|MATCH */
#line 1129 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3263 "parse.c"
        break;
      case 163: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1130 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3268 "parse.c"
        break;
      case 164: /* expr ::= expr likeop expr */
#line 1131 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy190.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy190.pExpr);
  yymsp[-2].minor.yy190.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy190);
  yymsp[-2].minor.yy190.zEnd = yymsp[0].minor.yy190.zEnd;
  if( yymsp[-2].minor.yy190.pExpr ) yymsp[-2].minor.yy190.pExpr->flags |= EP_InfixFunc;
}
#line 3283 "parse.c"
        break;
      case 165: /* expr ::= expr likeop expr ESCAPE expr */
#line 1142 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy190.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy190.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy190.pExpr);
  yymsp[-4].minor.yy190.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy190);
  yymsp[-4].minor.yy190.zEnd = yymsp[0].minor.yy190.zEnd;
  if( yymsp[-4].minor.yy190.pExpr ) yymsp[-4].minor.yy190.pExpr->flags |= EP_InfixFunc;
}
#line 3299 "parse.c"
        break;
      case 166: /* expr ::= expr IS NULL */
#line 1172 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy190,&yymsp[0].minor.yy0);}
#line 3304 "parse.c"
        break;
      case 167: /* expr ::= expr IS NOT NULL */
#line 1173 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy190,&yymsp[0].minor.yy0);}
#line 3309 "parse.c"
        break;
      case 168: /* expr ::= NOT expr */
      case 169: /* expr ::= BITNOT expr */ yytestcase(yyruleno==169);
#line 1195 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy190,pParse,yymsp[-1].major,&yymsp[0].minor.yy190,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3315 "parse.c"
        break;
      case 170: /* expr ::= MINUS expr */
#line 1199 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy190,pParse,TK_UMINUS,&yymsp[0].minor.yy190,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3320 "parse.c"
        break;
      case 171: /* expr ::= PLUS expr */
#line 1201 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy190,pParse,TK_UPLUS,&yymsp[0].minor.yy190,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3325 "parse.c"
        break;
      case 172: /* between_op ::= BETWEEN */
      case 175: /* in_op ::= IN */ yytestcase(yyruleno==175);
#line 1204 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = 0;}
#line 3331 "parse.c"
        break;
      case 174: /* expr ::= expr between_op expr AND expr */
#line 1206 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy190.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy190.pExpr);
  yymsp[-4].minor.yy190.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy190.pExpr, 0);
  if( yymsp[-4].minor.yy190.pExpr ){
    yymsp[-4].minor.yy190.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy58, &yymsp[-4].minor.yy190);
  yymsp[-4].minor.yy190.zEnd = yymsp[0].minor.yy190.zEnd;
}
#line 3347 "parse.c"
        break;
      case 177: /* expr ::= expr in_op LP exprlist RP */
#line 1221 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy412==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy190.pExpr, false);
    yymsp[-4].minor.yy190.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &sqlIntTokens[yymsp[-3].minor.yy58]);
    if (yymsp[-4].minor.yy190.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
  }else if( yymsp[-1].minor.yy412->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy412->a[0].pExpr;
    yymsp[-1].minor.yy412->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy412);
    yymsp[-4].minor.yy190.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy58 ? TK_NE : TK_EQ, yymsp[-4].minor.yy190.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy190.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy190.pExpr, 0);
    if( yymsp[-4].minor.yy190.pExpr ){
      yymsp[-4].minor.yy190.pExpr->x.pList = yymsp[-1].minor.yy412;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy190.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy412);
    }
    exprNot(pParse, yymsp[-3].minor.yy58, &yymsp[-4].minor.yy190);
  }
  yymsp[-4].minor.yy190.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3395 "parse.c"
        break;
      case 178: /* expr ::= LP select RP */
#line 1265 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy190,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy190.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy190.pExpr, yymsp[-1].minor.yy99);
}
#line 3404 "parse.c"
        break;
      case 179: /* expr ::= expr in_op LP select RP */
#line 1270 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy190.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy190.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy190.pExpr, yymsp[-1].minor.yy99);
  exprNot(pParse, yymsp[-3].minor.yy58, &yymsp[-4].minor.yy190);
  yymsp[-4].minor.yy190.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3414 "parse.c"
        break;
      case 180: /* expr ::= expr in_op nm paren_exprlist */
#line 1276 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy412 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy412);
  yymsp[-3].minor.yy190.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy190.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy190.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy58, &yymsp[-3].minor.yy190);
  yymsp[-3].minor.yy190.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3431 "parse.c"
        break;
      case 181: /* expr ::= EXISTS LP select RP */
#line 1289 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy190,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy190.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy99);
}
#line 3441 "parse.c"
        break;
      case 182: /* expr ::= CASE case_operand case_exprlist case_else END */
#line 1297 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy190,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy190.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy44, 0);
  if( yymsp[-4].minor.yy190.pExpr ){
    yymsp[-4].minor.yy190.pExpr->x.pList = yymsp[-1].minor.yy44 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy412,yymsp[-1].minor.yy44) : yymsp[-2].minor.yy412;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy190.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy412);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy44, false);
  }
}
#line 3456 "parse.c"
        break;
      case 183: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1310 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy412, yymsp[-2].minor.yy190.pExpr);
  yymsp[-4].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy412, yymsp[0].minor.yy190.pExpr);
}
#line 3464 "parse.c"
        break;
      case 184: /* case_exprlist ::= WHEN expr THEN expr */
#line 1314 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy412 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy190.pExpr);
  yymsp[-3].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy412, yymsp[0].minor.yy190.pExpr);
}
#line 3472 "parse.c"
        break;
      case 187: /* case_operand ::= expr */
#line 1324 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy44 = yymsp[0].minor.yy190.pExpr; /*A-overwrites-X*/}
#line 3477 "parse.c"
        break;
      case 190: /* nexprlist ::= nexprlist COMMA expr */
#line 1335 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy412 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy412,yymsp[0].minor.yy190.pExpr);}
#line 3482 "parse.c"
        break;
      case 191: /* nexprlist ::= expr */
#line 1337 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy412 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy190.pExpr); /*A-overwrites-Y*/}
#line 3487 "parse.c"
        break;
      case 193: /* paren_exprlist ::= LP exprlist RP */
      case 198: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==198);
#line 1344 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy412 = yymsp[-1].minor.yy412;}
#line 3493 "parse.c"
        break;
      case 194: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1350 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy412, yymsp[-8].minor.yy58,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy58);
  sql_create_index(pParse);
}
#line 3507 "parse.c"
        break;
      case 195: /* uniqueflag ::= UNIQUE */
#line 1362 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = SQL_INDEX_TYPE_UNIQUE;}
#line 3512 "parse.c"
        break;
      case 196: /* uniqueflag ::= */
#line 1363 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy58 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3517 "parse.c"
        break;
      case 199: /* eidlist ::= eidlist COMMA nm */
#line 1398 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy412 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy412, &yymsp[0].minor.yy0);
}
#line 3524 "parse.c"
        break;
      case 200: /* eidlist ::= nm */
#line 1401 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[0].minor.yy412 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3531 "parse.c"
        break;
      case 201: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1408 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy367, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy58);
  sql_drop_index(pParse);
}
#line 3539 "parse.c"
        break;
      case 202: /* cmd ::= PRAGMA nm */
#line 1415 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0,0);
}
#line 3546 "parse.c"
        break;
      case 203: /* cmd ::= PRAGMA nm EQ nmnum */
#line 1418 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0,0);
}
#line 3553 "parse.c"
        break;
      case 204: /* cmd ::= PRAGMA nm LP nmnum RP */
#line 1421 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0,0);
}
#line 3560 "parse.c"
        break;
      case 205: /* cmd ::= PRAGMA nm EQ minus_num */
#line 1424 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0,1);
}
#line 3567 "parse.c"
        break;
      case 206: /* cmd ::= PRAGMA nm LP minus_num RP */
#line 1427 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0,1);
}
#line 3574 "parse.c"
        break;
      case 207: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1430 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0,0);
}
#line 3581 "parse.c"
        break;
      case 208: /* cmd ::= PRAGMA */
#line 1433 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    sqlPragma(pParse, 0,0,0,0);
}
#line 3588 "parse.c"
        break;
      case 211: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1450 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = false;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy203, &all);
}
#line 3599 "parse.c"
        break;
      case 212: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1460 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy367, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy58, yymsp[-4].minor.yy234.a, yymsp[-4].minor.yy234.b, yymsp[0].minor.yy44,
                          yymsp[-7].minor.yy58);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3609 "parse.c"
        break;
      case 213: /* trigger_time ::= BEFORE */
#line 1468 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = TK_BEFORE; }
#line 3614 "parse.c"
        break;
      case 214: /* trigger_time ::= AFTER */
#line 1469 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = TK_AFTER;  }
#line 3619 "parse.c"
        break;
      case 215: /* trigger_time ::= INSTEAD OF */
#line 1470 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = TK_INSTEAD;}
#line 3624 "parse.c"
        break;
      case 216: /* trigger_time ::= */
#line 1471 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[1].minor.yy58 = TK_BEFORE; }
#line 3629 "parse.c"
        break;
      case 217: /* trigger_event ::= DELETE|INSERT */
      case 218: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==218);
#line 1475 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy234.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy234.b = 0;}
#line 3635 "parse.c"
        break;
      case 219: /* trigger_event ::= UPDATE OF idlist */
#line 1477 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[-2].minor.yy234.a = TK_UPDATE; yymsp[-2].minor.yy234.b = yymsp[0].minor.yy258;}
#line 3640 "parse.c"
        break;
      case 220: /* foreach_clause ::= */
#line 1479 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC, "FOR EACH STATEMENT "
	       "triggers are not implemented, please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3649 "parse.c"
        break;
      case 221: /* when_clause ::= */
#line 1488 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[1].minor.yy44 = 0; }
#line 3654 "parse.c"
        break;
      case 222: /* when_clause ::= WHEN expr */
#line 1489 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy44 = yymsp[0].minor.yy190.pExpr; }
#line 3659 "parse.c"
        break;
      case 223: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1493 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy203!=0 );
  yymsp[-2].minor.yy203->pLast->pNext = yymsp[-1].minor.yy203;
  yymsp[-2].minor.yy203->pLast = yymsp[-1].minor.yy203;
}
#line 3668 "parse.c"
        break;
      case 224: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1498 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy203!=0 );
  yymsp[-1].minor.yy203->pLast = yymsp[-1].minor.yy203;
}
#line 3676 "parse.c"
        break;
      case 225: /* trnm ::= nm DOT nm */
#line 1509 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC, "qualified table names are not "\
           "allowed on INSERT, UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3686 "parse.c"
        break;
      case 226: /* tridxby ::= INDEXED BY nm */
#line 1521 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX, "trigger body", "the INDEXED BY clause "\
           "is not allowed on UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3695 "parse.c"
        break;
      case 227: /* tridxby ::= NOT INDEXED */
#line 1526 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX, "trigger body", "the NOT INDEXED "\
           "clause is not allowed on UPDATE or DELETE statements within "\
           "triggers");
  pParse->is_aborted = true;
}
#line 3705 "parse.c"
        break;
      case 228: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1539 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy203 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy412, yymsp[0].minor.yy44, yymsp[-5].minor.yy58);
     if (yymsp[-6].minor.yy203 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3716 "parse.c"
        break;
      case 229: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1548 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  /*yylhsminor.yy203-overwrites-yymsp[-4].minor.yy58. */
  yylhsminor.yy203 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy258, yymsp[0].minor.yy99, yymsp[-4].minor.yy58);
  if (yylhsminor.yy203 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3728 "parse.c"
  yymsp[-4].minor.yy203 = yylhsminor.yy203;
        break;
      case 230: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1558 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy203 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy44);
  if (yymsp[-4].minor.yy203 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3740 "parse.c"
        break;
      case 231: /* trigger_cmd ::= select */
#line 1567 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  /* yylhsminor.yy203-overwrites-yymsp[0].minor.yy99. */
  yylhsminor.yy203 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy99);
  if (yylhsminor.yy203 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3752 "parse.c"
  yymsp[0].minor.yy203 = yylhsminor.yy203;
        break;
      case 232: /* expr ::= RAISE LP IGNORE RP */
#line 1577 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy190,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy190.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy190.pExpr ){
    yymsp[-3].minor.yy190.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 3764 "parse.c"
        break;
      case 233: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1584 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy190,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy190.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy190.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy190.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy58;
}
#line 3777 "parse.c"
        break;
      case 234: /* raisetype ::= ROLLBACK */
#line 1595 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 3782 "parse.c"
        break;
      case 235: /* raisetype ::= ABORT */
#line 1596 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = ON_CONFLICT_ACTION_ABORT;}
#line 3787 "parse.c"
        break;
      case 236: /* raisetype ::= FAIL */
#line 1597 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[0].minor.yy58 = ON_CONFLICT_ACTION_FAIL;}
#line 3792 "parse.c"
        break;
      case 237: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1601 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy58);
  sql_drop_trigger(pParse);
}
#line 3801 "parse.c"
        break;
      case 238: /* alter_table_start ::= ALTER TABLE fullname */
#line 1617 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-2].minor.yy254 = yymsp[0].minor.yy367; }
#line 3806 "parse.c"
        break;
      case 239: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1620 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yylhsminor.yy206.table_name = yymsp[-3].minor.yy254;
  yylhsminor.yy206.name = yymsp[0].minor.yy0;
}
#line 3814 "parse.c"
  yymsp[-3].minor.yy206 = yylhsminor.yy206;
        break;
      case 240: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1626 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy206.table_name, &yymsp[-11].minor.yy206.name, yymsp[-7].minor.yy412, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy412,
                     yymsp[-2].minor.yy58, yymsp[-1].minor.yy58, yymsp[0].minor.yy58);
  sql_create_foreign_key(pParse);
}
#line 3824 "parse.c"
        break;
      case 241: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1632 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy206.table_name, &yymsp[-4].minor.yy206.name, yymsp[-1].minor.yy412, yymsp[-3].minor.yy58,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 3833 "parse.c"
        break;
      case 242: /* unique_spec ::= UNIQUE */
#line 1639 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy58 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 3838 "parse.c"
        break;
      case 243: /* unique_spec ::= PRIMARY KEY */
#line 1640 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy58 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 3843 "parse.c"
        break;
      case 244: /* cmd ::= alter_table_start RENAME TO nm */
#line 1642 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy254, &yymsp[0].minor.yy0);
    sql_alter_table_rename(pParse);
}
#line 3851 "parse.c"
        break;
      case 245: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1647 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  drop_fk_def_init(&pParse->drop_fk_def, yymsp[-3].minor.yy367, &yymsp[0].minor.yy0, false);
  sql_drop_foreign_key(pParse);
}
#line 3859 "parse.c"
        break;
      case 246: /* with ::= */
#line 1658 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{yymsp[1].minor.yy91 = 0;}
#line 3864 "parse.c"
        break;
      case 247: /* with ::= WITH wqlist */
#line 1660 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-1].minor.yy91 = yymsp[0].minor.yy91; }
#line 3869 "parse.c"
        break;
      case 248: /* with ::= WITH RECURSIVE wqlist */
#line 1661 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[-2].minor.yy91 = yymsp[0].minor.yy91; }
#line 3874 "parse.c"
        break;
      case 249: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1663 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy91 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy412, yymsp[-1].minor.yy99); /*A-overwrites-X*/
}
#line 3881 "parse.c"
        break;
      case 250: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1666 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy91 = sqlWithAdd(pParse, yymsp[-7].minor.yy91, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy412, yymsp[-1].minor.yy99);
}
#line 3888 "parse.c"
        break;
      case 251: /* typedef ::= TEXT */
#line 1673 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy438.type = FIELD_TYPE_STRING; }
#line 3893 "parse.c"
        break;
      case 252: /* typedef ::= SCALAR */
#line 1674 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy438.type = FIELD_TYPE_SCALAR; }
#line 3898 "parse.c"
        break;
      case 253: /* char_len ::= LP INTEGER RP */
#line 1685 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy58;
  (void) yymsp[-1].minor.yy0;
}
#line 3906 "parse.c"
        break;
      case 254: /* typedef ::= VARCHAR char_len */
#line 1691 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy438.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy58;
}
#line 3914 "parse.c"
        break;
      case 255: /* number_typedef ::= FLOAT_KW|REAL|DOUBLE */
#line 1698 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy438.type = FIELD_TYPE_NUMBER; }
#line 3919 "parse.c"
        break;
      case 256: /* number_typedef ::= INT|INTEGER_KW */
#line 1699 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"
{ yymsp[0].minor.yy438.type = FIELD_TYPE_INTEGER; }
#line 3924 "parse.c"
        break;
      default:
      /* (257) input ::= ecmd */ yytestcase(yyruleno==257);
      /* (258) explain ::= */ yytestcase(yyruleno==258);
      /* (259) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=259);
      /* (260) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==260);
      /* (261) savepoint_opt ::= */ yytestcase(yyruleno==261);
      /* (262) cmd ::= create_table create_table_args */ yytestcase(yyruleno==262);
      /* (263) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==263);
      /* (264) columnlist ::= columnlist COMMA columnname carglist */ yytestcase(yyruleno==264);
      /* (265) columnlist ::= columnname carglist */ yytestcase(yyruleno==265);
      /* (266) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=266);
      /* (267) carglist ::= carglist ccons */ yytestcase(yyruleno==267);
      /* (268) carglist ::= */ yytestcase(yyruleno==268);
      /* (269) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=269);
      /* (270) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=270);
      /* (271) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=271);
      /* (272) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=272);
      /* (273) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=273);
      /* (274) oneselect ::= values */ yytestcase(yyruleno==274);
      /* (275) sclp ::= selcollist COMMA */ yytestcase(yyruleno==275);
      /* (276) as ::= ID|STRING */ yytestcase(yyruleno==276);
      /* (277) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==277);
      /* (278) join_nm ::= JOIN_KW */ yytestcase(yyruleno==278);
      /* (279) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=279);
      /* (280) type_func ::= CHAR */ yytestcase(yyruleno==280);
      /* (281) exprlist ::= nexprlist */ yytestcase(yyruleno==281);
      /* (282) nmnum ::= plus_num (OPTIMIZED OUT) */ assert(yyruleno!=282);
      /* (283) nmnum ::= STRING */ yytestcase(yyruleno==283);
      /* (284) nmnum ::= nm */ yytestcase(yyruleno==284);
      /* (285) nmnum ::= ON */ yytestcase(yyruleno==285);
      /* (286) nmnum ::= DELETE */ yytestcase(yyruleno==286);
      /* (287) nmnum ::= DEFAULT */ yytestcase(yyruleno==287);
      /* (288) plus_num ::= INTEGER|FLOAT */ yytestcase(yyruleno==288);
      /* (289) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==289);
      /* (290) trnm ::= nm */ yytestcase(yyruleno==290);
      /* (291) tridxby ::= */ yytestcase(yyruleno==291);
      /* (292) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=292);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.1.3.9/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, TOKEN.n, TOKEN.z,
             TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, TOKEN.n, TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4030 "parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
